/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
#define _HEAVY_CONTEXT_WSTD_MANGLR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlIf.h"
#include "HvControlVar.h"
#include "HvSignalEnvelope.h"
#include "HvMath.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvControlCast.h"
#include "HvControlDelay.h"

class Heavy_WSTD_MANGLR : public HeavyContext {

 public:
  Heavy_WSTD_MANGLR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_MANGLR();

  const char *getName() override { return "WSTD_MANGLR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CRSHR = 0xE2DA4DC3, // Crshr
        FLDR = 0xE42C892E, // Fldr
        GAIN = 0x677821DA, // Gain
        LMTR = 0xCB23DC60, // Lmtr
        MIX = 0x97D46AC6, // Mix
        SMTHR = 0xD88E26F9, // Smthr
        SQNC = 0x53F863DB, // Sqnc
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_En5e49RQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JTWgeGDp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jDSqbDFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8YEk0njX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GropFVbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JoCleuhV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_50Cmp9yc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5QIMjxjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_whwD4ChO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4VOxZU9d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_miILum80_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ji4lk8V5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_blpAr6Fx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pbwm43QQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LaE6xr3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Xhp43NnP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gkjmkDor_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rqRZQSIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LA2b11BP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PRuM8cl8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L7PiPclD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1URAECSm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_QzNAzUw2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IgPW45jS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Bpf5NiXu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8IzKuNeQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2XhnnJ0m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7GZCqMF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WiDUZRVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Jm1YXacb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bmXYw0Aj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_KED4XyaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rTeoDoTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c51EPA97_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rPY786TS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1FQBbFHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5uuWTB1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4YO1wV99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqFZhUvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pSIaqLYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kkJlyhoQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GYLU28Gf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_NiEJ09Kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KM86fMXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x6XvrE0R_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7JHakEB6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EgIN74GD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nmCUxTvz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qteGiY2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xqW1GlTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TEwSqYyE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IdmWq0JQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mzqbxUYH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8RXZBsQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yybwah4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oyzYAiyZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_rSAbECU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BL9LeLFS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_heWDD1PR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_B3Gb41C0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y4bv7g1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_70oi7q5x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Bu18oHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hBGmthC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CABxv5l8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UqvSOYJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W1PwK5Nj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FGaxCVSS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OLGdFGjk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BvLeo5bu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ci8BpZm3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IWM6LcgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_sghHpzzz_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_PcP1uLCX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Eym4v5Yh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kfZSqSRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OrfZ3EOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rut52QA0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eugCdvt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kcjG8swG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rgh21G9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5QZaa2hj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dXqHkMBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_04bnDI6j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_OTDPbewU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_o686E9De_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qsonI4Xe_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Az2bs9tH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ak8EYYwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ACWgEHzS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_inbD5252_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KenXcDnj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UbdRvUJz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A5ZPF5eI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WhhmJ86u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JkBRnzFD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cPsdUByX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ys0OEkqk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_256PNUG7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_25QViC09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_8BC1AU40_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_xL4dxua7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XSwixHQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OKRtDdd5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wwmJfpVX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_abbrPaVa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tT0kxRC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XaxR5STq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kinRYfyQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_udn9nsQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oWcXAksM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r5cGr2eC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7PtRxhMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CsLslWc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rvYbSy1c_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_Q86HlJy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_25MNE9FG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wLhVzJVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xAG3uXgT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KEzk3brU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VV2OLaua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hQOJnyH9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rznvoh3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xzapFY3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lzMd830N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jnNzZMyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_euYJN051_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ow6CofPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LEm6yGV5_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_cOnydjfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Wo4ULWVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QEwFbUTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UNdNvvKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rk85D6Kl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5Rg87Rsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yrEj3p5J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9ExaVeU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O3lAsrL3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1hHuLUuW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yFWlY4rd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7lSxrZUY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_AoCrvea8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_cjCLtrDM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_YLpZWJXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g3HdaGzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1pM91fng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yTwqEYPE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_54Y2yOFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qc7FMNGc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1mrbWpj4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O9RAK24n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PVHPIkiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rhjimm31_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vTbiVs18_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_z7nyvqlW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fy5lGSMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ebGEmA4L_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_yX4wb0Sw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K7OKU9Od_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uRquMha2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hHxMlgQ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mKK5zsxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3XA6TJms_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hznjXeab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nLunlF8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qjUwZo1r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EhDTLTSS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QEL2ySLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_U4VooVIq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ppG3N2T3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zM7jtVq9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lg8FXKhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hvXyk6gZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_617vxmj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jreLe1y0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TqUPhcUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DLxHyDQF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X7gWuolJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XkgjYRmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m3zOnn4U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ix0kQDWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cQMGbkbQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dscfBqtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZBdMawhn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6xa2M1iv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_N8ttpbUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IZlh42GT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gw5rqF6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CTPMcNL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TFa4rSvN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plOVr7rb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_z7wJLLW7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_taZb51Af_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I5MzCW2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hLEV3gY3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W0NFDWKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NXY9P0I0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Alb3JvaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ldr0BLuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yxHWPS2M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N4A9TZw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j4zN6X4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9PfSpQqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_No3efkEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WBzYfMGL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L6xCuRs6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZSOXPWMH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vkWE4KHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BVR4gIpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LagQv5fR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RDFYByyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q5HEzuEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SfONNcCh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_biaGuuip_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yrEbpUKs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ysyMv2j2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X715amrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B4kmFF7O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VxTGj3Ko_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qh6snOSR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NxpqUzFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ZzrPNe6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GFHqNjJF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SMg3BVMQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wI7EfUrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DBuNgZyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_B4RzEZyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jDpEIG8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7O72BfKf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1lE4lAxj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZA13s01f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i8nha4cZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LeGQiZYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8hieoj05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FAYZBrGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vxhhOOKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NkgIMhAy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KtAamJMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7t5prrqp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SCogZQnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4i5fYZFj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BSxyMGyW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_V4EKEQ6O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mSxIhTV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CTLx5jik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ikJt04rK_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Dif9OV9n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_jI7ZH33A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y2RAjHf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_VoePi0cl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_YB56E76m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GNLQ9iQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_q3j1pDJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vTT2mXS7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_a8lI3nA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TUeoXgkL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_43Q1HOPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_bbHieaYk_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GDWw29PN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mQuOaVYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0pMUIvNs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LPFfxy82_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_3okuBU4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0HxQchO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6bq6QQVL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HEjRNqk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IMvZvH9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9UVVq2co_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_H7YTb8sx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_TFESkRSJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ALpFKYtB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AD5VjtM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UeflP7pA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qQbra6Tl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HXq0YwHQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1rug4fge_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4azfOEQV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1y0V0GQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jgg7kAIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zWQBKEsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nRtw1YMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4piWUTlr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L9E19BSA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jLTfx8it_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SpqKy5ZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8n7yHsur_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_58y3laac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zTU6GXV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FmTrS5qt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BPqBhXXd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0EU6AwRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8jncoog1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L0adq96C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hMATduqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oyybR0TC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KPP8Il8i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nWATq0jY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oO8LrY78_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3huzPwC4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MTypVfPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3gnidjrY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_QyfAYDz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tvm4qvBz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nM5tCNW1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XhrlUn8Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0a1GfVzO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rChOEXl2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PPzQRvyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_KWv2AcDX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_aFYIOg2h_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_llpQx1HR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hcQzu7ei_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aCIW54JS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_74S6PjQC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R8gomU33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_INCnZH6J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fzOG7Z6i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2Yq3tzJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ywyhV7Mr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C3I83wVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_apmgdUDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ped1R0Cx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6t7r7ohM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Rx03boMn_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_sBXtyxAi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MS3JWAse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jrAVBmsC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x4HZq0t6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8NTL4iXg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K7rdQsam_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rHgNttpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2R1SiYhB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GqCRvNRC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rjDh6RWm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PWGgG5xP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_M9dnfl9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DkGdK4je_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hRY3pLEc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_sggvEQm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PhyKbRfm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QQRmyINW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DEGrO4St_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y7Sb8wqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gq9YbaFh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tDeTKiYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WGlJrf1F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FC4TQvkz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Sl0YGxGX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n8B9Eorl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_fEHVDoHc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_iIG8z9yt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_vcvUhHpl_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_wNGZRQ85_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eekmRhHZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HPwVH8fp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eWJ4Di6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sEV6MwhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gaHnCwtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_asGxHcOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j8lSoX72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9H3JebjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L5xB48E5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_91aohLvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vsavgQ0D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8WxuceYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_x2oA0NwO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_lRj7wLaz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pMAln3K8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xkHV5J3y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YkDUOvMR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yTLacEJN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_39hKwaA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CCIYMOId_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9q4F1kAc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p2J63SF1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kOkXv0Pe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MYcLNsFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dCPL9VjR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_y1NRpn7t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_geRgGBez_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_s9H8mruo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dAAZjeI6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P3EVfBVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_37paZZiS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iI1ovW82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pbPXQHWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Qz0JdM72_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wjcRuY87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_p52cuLGe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IGmso5pf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eCtR5I99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_isQoYune_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_YjX4Eb9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ToBTk2fd_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_L3qJut1D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wOmk2SzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rVIhhFOJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XDptWZGF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RodfGRjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NItFWudf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jYaHiZbR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KWyTMQk1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_T23ez4PD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b9nxt4D3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8sHranL0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_326pftmf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lpb9BCDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_SHlFsfsb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_hNXch6X4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0f2HMEFq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X8dbu2kK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_er2ad3NM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3dCJeADb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_etTHy2Eb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AuMi7uhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NV1swqLs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v2TXZgJY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_a0L9O8rK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ov8Pd0d0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TYCHs4j7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jbsFYARc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PAbUD6Ys_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_2hOEip7U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jq479oMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ms0rTFoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L5DH9B2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uFCdul2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OhIkKGHf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jMiKaO7B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IgKlcSrF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HukhVB2X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Up0nd9Pb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b9Icdwyk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BnzmFduf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_8vSEYaNz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hSXyczwM_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_f6kzetEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c4DUK9Hk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aKCnzAbC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8HXFiBP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6rDooRNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UswkGUMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eMlrqtaM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yYTGJUzo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FdbtOeeE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Vce5rR6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KumqTbxd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_CdHooQJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2rAZ7eA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kZJJI26c_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_UM5j3guS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fzGQPgOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cey4ItMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gGVkVGhH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AJob8Akl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qwEtN7xI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zjBoeYCZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_30fb79AW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FVKIxH6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rOaAPNAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rfkMAiCz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Rilrslz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zVDUrtc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lkHgbmvp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_guEmzF4d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YLZ6wjF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lHmWtYW8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5kOxNmp1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aimVlW5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3odmY0eX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pdCL7IYL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GSHapCEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_icZh4rlC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eAkr44u5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KXjyFcQH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_akD7ABTK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5xVifGEo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zi0QNVoV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T2eAuBkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Qz42DjJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XgCFVtmv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BlhUQv4m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_18gvczkR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qVCyYeZv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Ze0aTAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bkuqn0rU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gBDyXjgt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D94qc2dH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p0DZZzt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aT6ePGOa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wBA984p0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zHQK7cd3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AC990CTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oljzandX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EC4d8F6n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_VTNT66zJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cBjbFqQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_msMoiaIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CPBvGS77_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qa8mAMxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8GWOvjhq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JiYtQdo0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7SJ0rPfF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yvCPsyHU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wd1T3Qzj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nxbk4k7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZChkIWhh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rKAHLR8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_usMfxR4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WRP0nwlh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JRVObvxo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Snedp0Y4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UsM53QNv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0JC2x7wk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FvYPStaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5f0ixu9U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FMTpLbxQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jN1UxAbW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kwx14rqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PUf6eJ3T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_7t1VdY7V_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_AYjBUqu4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L1UYjPJ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_glJc7taX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WRJ0aLaH_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7bf8o5fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pU8MdmVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mZpIvdmA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_piW1oxdR_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_SeJ3ER0g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_U8OI3DhF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Uc833hDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TfYmGpQP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_43oipOrH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ACbcRTQZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_oLpPPKrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_kJlLZkz1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_jXZ4ZJbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7qzLFXf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gK7Omk6t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_F70XM4li_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cDelay_7HBM9dgZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BWxUzRCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rF0wp3gv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YCjk33GS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ajW4DVTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_FR7pgYfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_QImdAypF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void sEnv_EWNgFNwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ols64H1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IhxdDzQU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zn6nfc98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yTmwIorF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ser1i45H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wqCDokfq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bcWLRWbM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_01Bim7zu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q0hzet1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tf6ou2Wg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VbafmVT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S2EE06sV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RtQbz2AY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MJw5j7RJ_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6mGm0U5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lhuw3fIM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Z4rycLYE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fwHbN8xX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fRs7RE8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lEoeiMvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HgssAcWI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_USsNmrQd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vZheyvk3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xTGAC3mJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wYObGNMW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zRpt6ZYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BK7jLrPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SUN7OFeG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FS3jEYjT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5Wl3MPF0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YeQSLYkz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_23yPFRU2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n06vLOEi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5VcXYvE7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hQMPyVij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vqyLxUOX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GxPafQem_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KLSzm3k0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qEWiF8bK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ofhwRpdN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xHWf0cTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DUPzdKHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RcoHujZk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kVY6SkOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cRLfsysc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E77lo2FU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bGqHv10U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ymBAWkfk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EQCYsFW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DW9RFNHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BSKUp0uP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tCCMFW09_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JMxcAkm7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9hMbRPGt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6dNGSs3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IL5oL3wH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_rqap1zsf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0rjgeTYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_AiZotM6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R2woWGt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hyHddeDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DusBExB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XoxzzGzZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pMmR5zFV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_75yzm06f_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_jzsdNaYm;
  SignalLine sLine_nCkqt59U;
  SignalLine sLine_jF0Y2asR;
  SignalLine sLine_C2bPcCay;
  SignalLine sLine_WW7ak4vb;
  SignalLine sLine_KIP3Sycb;
  SignalLine sLine_RQtLcHpg;
  SignalLine sLine_pd3omEAd;
  SignalLine sLine_E352qLFW;
  SignalLine sLine_7oqO1iEt;
  SignalLine sLine_Az7lmNHU;
  SignalLine sLine_53zPH6kP;
  SignalEnvelope sEnv_H7YTb8sx;
  SignalEnvelope sEnv_TFESkRSJ;
  SignalLine sLine_Sjs09Sbn;
  SignalLine sLine_ild1tk0M;
  SignalLine sLine_KhzK8kGL;
  SignalLine sLine_d6g5m1uh;
  SignalLine sLine_PPzwPZb1;
  SignalLine sLine_UOhtJSe0;
  SignalLine sLine_BzgbXKfX;
  SignalLine sLine_S7cMoNSG;
  SignalLine sLine_t3I1cexD;
  SignalLine sLine_IqbIOaMP;
  SignalLine sLine_hYZx748e;
  SignalLine sLine_lETb5IG1;
  SignalLine sLine_GuGVgj7U;
  SignalLine sLine_NvzKyEBd;
  SignalLine sLine_ttL8AaaY;
  SignalLine sLine_DgQKzH8s;
  SignalLine sLine_SITd45gn;
  SignalLine sLine_R6E5LEgd;
  SignalEnvelope sEnv_QImdAypF;
  SignalEnvelope sEnv_EWNgFNwY;
  SignalLine sLine_kVq9LUeB;
  SignalLine sLine_LrL9CPCH;
  SignalLine sLine_pVIQlwOl;
  SignalLine sLine_bYxnjsfj;
  SignalLine sLine_ZUqkRzHO;
  SignalLine sLine_L01SeuM5;
  SignalLine sLine_flgTNvt7;
  SignalLine sLine_iK1pN3x2;
  ControlVar cVar_En5e49RQ;
  ControlBinop cBinop_JTWgeGDp;
  ControlBinop cBinop_jDSqbDFP;
  ControlBinop cBinop_8YEk0njX;
  ControlBinop cBinop_GropFVbO;
  ControlBinop cBinop_5QIMjxjN;
  ControlBinop cBinop_4VOxZU9d;
  ControlBinop cBinop_miILum80;
  ControlBinop cBinop_Ji4lk8V5;
  ControlVar cVar_blpAr6Fx;
  ControlVar cVar_pbwm43QQ;
  ControlVar cVar_LaE6xr3f;
  ControlVar cVar_Xhp43NnP;
  ControlVar cVar_gkjmkDor;
  ControlBinop cBinop_rqRZQSIb;
  ControlVar cVar_PRuM8cl8;
  ControlVar cVar_L7PiPclD;
  ControlIf cIf_WiDUZRVL;
  ControlIf cIf_Jm1YXacb;
  ControlDelay cDelay_KED4XyaM;
  ControlBinop cBinop_rPY786TS;
  ControlBinop cBinop_1FQBbFHQ;
  ControlIf cIf_NiEJ09Kz;
  ControlIf cIf_KM86fMXo;
  ControlDelay cDelay_7JHakEB6;
  ControlBinop cBinop_qteGiY2d;
  ControlBinop cBinop_xqW1GlTg;
  ControlIf cIf_rSAbECU3;
  ControlIf cIf_BL9LeLFS;
  ControlDelay cDelay_B3Gb41C0;
  ControlBinop cBinop_3Bu18oHA;
  ControlBinop cBinop_hBGmthC8;
  ControlIf cIf_ci8BpZm3;
  ControlIf cIf_IWM6LcgK;
  ControlDelay cDelay_PcP1uLCX;
  ControlBinop cBinop_OrfZ3EOJ;
  ControlBinop cBinop_rut52QA0;
  ControlIf cIf_OTDPbewU;
  ControlIf cIf_o686E9De;
  ControlDelay cDelay_Az2bs9tH;
  ControlBinop cBinop_inbD5252;
  ControlBinop cBinop_KenXcDnj;
  ControlIf cIf_256PNUG7;
  ControlIf cIf_25QViC09;
  ControlDelay cDelay_xL4dxua7;
  ControlBinop cBinop_wwmJfpVX;
  ControlBinop cBinop_abbrPaVa;
  ControlIf cIf_7PtRxhMb;
  ControlIf cIf_CsLslWc1;
  ControlDelay cDelay_Q86HlJy7;
  ControlBinop cBinop_xAG3uXgT;
  ControlBinop cBinop_KEzk3brU;
  ControlIf cIf_euYJN051;
  ControlIf cIf_ow6CofPp;
  ControlDelay cDelay_cOnydjfl;
  ControlBinop cBinop_UNdNvvKd;
  ControlBinop cBinop_rk85D6Kl;
  ControlIf cIf_7lSxrZUY;
  ControlIf cIf_AoCrvea8;
  ControlDelay cDelay_YLpZWJXe;
  ControlBinop cBinop_yTwqEYPE;
  ControlBinop cBinop_54Y2yOFz;
  ControlIf cIf_z7nyvqlW;
  ControlIf cIf_fy5lGSMQ;
  ControlDelay cDelay_yX4wb0Sw;
  ControlBinop cBinop_hHxMlgQ1;
  ControlBinop cBinop_mKK5zsxq;
  ControlIf cIf_U4VooVIq;
  ControlIf cIf_ppG3N2T3;
  ControlDelay cDelay_lg8FXKhH;
  ControlBinop cBinop_jreLe1y0;
  ControlBinop cBinop_TqUPhcUy;
  ControlIf cIf_dscfBqtD;
  ControlIf cIf_ZBdMawhn;
  ControlDelay cDelay_N8ttpbUA;
  ControlBinop cBinop_CTPMcNL0;
  ControlBinop cBinop_TFa4rSvN;
  SignalVarf sVarf_8XjiEgp0;
  SignalVarf sVarf_NVDDVs3D;
  SignalVarf sVarf_RoECiHKO;
  SignalVarf sVarf_2PVSYIHL;
  SignalVarf sVarf_2RrpSq9x;
  SignalVarf sVarf_DHRHQZNt;
  SignalVarf sVarf_EJDFkc19;
  SignalVarf sVarf_02Pg92VY;
  ControlVar cVar_4i5fYZFj;
  ControlSlice cSlice_V4EKEQ6O;
  ControlVar cVar_mSxIhTV1;
  ControlSlice cSlice_Dif9OV9n;
  ControlVar cVar_jI7ZH33A;
  ControlSlice cSlice_YB56E76m;
  ControlVar cVar_GNLQ9iQS;
  ControlSlice cSlice_a8lI3nA7;
  ControlVar cVar_TUeoXgkL;
  ControlSlice cSlice_GDWw29PN;
  ControlVar cVar_mQuOaVYA;
  ControlDelay cDelay_3okuBU4O;
  ControlVar cVar_HEjRNqk3;
  ControlIf cIf_IMvZvH9x;
  ControlIf cIf_9UVVq2co;
  ControlBinop cBinop_ALpFKYtB;
  ControlBinop cBinop_UeflP7pA;
  ControlBinop cBinop_qQbra6Tl;
  ControlBinop cBinop_4azfOEQV;
  ControlBinop cBinop_Jgg7kAIw;
  ControlSlice cSlice_SpqKy5ZX;
  ControlVar cVar_8n7yHsur;
  SignalVarf sVarf_KHzI6wLs;
  SignalVarf sVarf_2y4iqu3u;
  SignalVarf sVarf_kMqRQs9k;
  SignalVarf sVarf_6ZDKlb3O;
  SignalVarf sVarf_iRA023Rq;
  SignalVarf sVarf_II8lJ8qw;
  ControlBinop cBinop_BPqBhXXd;
  ControlBinop cBinop_nWATq0jY;
  ControlVar cVar_3huzPwC4;
  ControlVar cVar_MTypVfPU;
  ControlIf cIf_PPzQRvyz;
  ControlIf cIf_KWv2AcDX;
  ControlDelay cDelay_llpQx1HR;
  ControlBinop cBinop_74S6PjQC;
  ControlBinop cBinop_R8gomU33;
  ControlIf cIf_ped1R0Cx;
  ControlIf cIf_6t7r7ohM;
  ControlDelay cDelay_sBXtyxAi;
  ControlBinop cBinop_x4HZq0t6;
  ControlBinop cBinop_8NTL4iXg;
  ControlIf cIf_M9dnfl9P;
  ControlIf cIf_DkGdK4je;
  ControlDelay cDelay_sggvEQm6;
  ControlBinop cBinop_DEGrO4St;
  ControlBinop cBinop_y7Sb8wqG;
  ControlIf cIf_fEHVDoHc;
  ControlIf cIf_iIG8z9yt;
  ControlDelay cDelay_wNGZRQ85;
  ControlBinop cBinop_eWJ4Di6k;
  ControlBinop cBinop_sEV6MwhP;
  ControlIf cIf_vsavgQ0D;
  ControlIf cIf_8WxuceYn;
  ControlDelay cDelay_lRj7wLaz;
  ControlBinop cBinop_YkDUOvMR;
  ControlBinop cBinop_yTLacEJN;
  ControlIf cIf_dCPL9VjR;
  ControlIf cIf_y1NRpn7t;
  ControlDelay cDelay_s9H8mruo;
  ControlBinop cBinop_37paZZiS;
  ControlBinop cBinop_iI1ovW82;
  ControlIf cIf_isQoYune;
  ControlIf cIf_YjX4Eb9w;
  ControlDelay cDelay_L3qJut1D;
  ControlBinop cBinop_XDptWZGF;
  ControlBinop cBinop_RodfGRjS;
  ControlIf cIf_326pftmf;
  ControlIf cIf_lpb9BCDg;
  ControlDelay cDelay_hNXch6X4;
  ControlBinop cBinop_er2ad3NM;
  ControlBinop cBinop_3dCJeADb;
  ControlIf cIf_TYCHs4j7;
  ControlIf cIf_jbsFYARc;
  ControlDelay cDelay_2hOEip7U;
  ControlBinop cBinop_L5DH9B2i;
  ControlBinop cBinop_uFCdul2r;
  ControlIf cIf_BnzmFduf;
  ControlIf cIf_8vSEYaNz;
  ControlDelay cDelay_f6kzetEp;
  ControlBinop cBinop_8HXFiBP9;
  ControlBinop cBinop_6rDooRNm;
  ControlIf cIf_CdHooQJs;
  ControlIf cIf_2rAZ7eA9;
  ControlDelay cDelay_UM5j3guS;
  ControlBinop cBinop_gGVkVGhH;
  ControlBinop cBinop_AJob8Akl;
  ControlIf cIf_Rilrslz6;
  ControlIf cIf_zVDUrtc1;
  ControlDelay cDelay_guEmzF4d;
  ControlBinop cBinop_5kOxNmp1;
  ControlBinop cBinop_aimVlW5B;
  SignalVarf sVarf_LaWHLmOD;
  SignalVarf sVarf_kuYco5E5;
  SignalVarf sVarf_mUrTflXh;
  SignalVarf sVarf_vh3mZbhX;
  SignalVarf sVarf_PhCT8Muq;
  SignalVarf sVarf_6U2Jw3bo;
  SignalVarf sVarf_fZcyKz6p;
  SignalVarf sVarf_5PpWaXzJ;
  ControlVar cVar_PUf6eJ3T;
  ControlSlice cSlice_AYjBUqu4;
  ControlVar cVar_L1UYjPJ2;
  ControlSlice cSlice_7bf8o5fz;
  ControlVar cVar_pU8MdmVI;
  ControlSlice cSlice_SeJ3ER0g;
  ControlVar cVar_U8OI3DhF;
  ControlSlice cSlice_43oipOrH;
  ControlVar cVar_ACbcRTQZ;
  ControlSlice cSlice_jXZ4ZJbD;
  ControlVar cVar_7qzLFXf7;
  ControlDelay cDelay_7HBM9dgZ;
  ControlVar cVar_YCjk33GS;
  ControlIf cIf_ajW4DVTm;
  ControlIf cIf_FR7pgYfO;
  ControlBinop cBinop_ols64H1e;
  ControlBinop cBinop_Zn6nfc98;
  ControlBinop cBinop_yTmwIorF;
  ControlBinop cBinop_bcWLRWbM;
  ControlBinop cBinop_q0hzet1g;
  ControlSlice cSlice_6mGm0U5u;
  ControlVar cVar_lhuw3fIM;
  SignalVarf sVarf_8nfgyzJx;
  SignalVarf sVarf_8ykUBkG2;
  SignalVarf sVarf_KNSsClXp;
  SignalVarf sVarf_6uwTpxkw;
  SignalVarf sVarf_uoYELukh;
  SignalVarf sVarf_v2n7U0Op;
  ControlBinop cBinop_lEoeiMvy;
  ControlBinop cBinop_BK7jLrPm;
  ControlVar cVar_FS3jEYjT;
  SignalVarf sVarf_VrHYT66W;
  SignalVarf sVarf_kQCxbOPc;
  SignalVarf sVarf_R6NJ7rH4;
  SignalVarf sVarf_VfMpuEw0;
  ControlBinop cBinop_hQMPyVij;
};

#endif // _HEAVY_CONTEXT_WSTD_MANGLR_HPP_
