/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_MANGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_MANGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_MANGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_MANGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_MANGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_MANGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_MANGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_MANGLR::Heavy_WSTD_MANGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_jzsdNaYm);
  numBytes += sLine_init(&sLine_nCkqt59U);
  numBytes += sLine_init(&sLine_jF0Y2asR);
  numBytes += sLine_init(&sLine_C2bPcCay);
  numBytes += sLine_init(&sLine_WW7ak4vb);
  numBytes += sLine_init(&sLine_KIP3Sycb);
  numBytes += sLine_init(&sLine_RQtLcHpg);
  numBytes += sLine_init(&sLine_pd3omEAd);
  numBytes += sLine_init(&sLine_E352qLFW);
  numBytes += sLine_init(&sLine_7oqO1iEt);
  numBytes += sLine_init(&sLine_Az7lmNHU);
  numBytes += sLine_init(&sLine_53zPH6kP);
  numBytes += sEnv_init(&sEnv_H7YTb8sx, 512, 256);
  numBytes += sEnv_init(&sEnv_TFESkRSJ, 512, 256);
  numBytes += sLine_init(&sLine_Sjs09Sbn);
  numBytes += sLine_init(&sLine_ild1tk0M);
  numBytes += sLine_init(&sLine_KhzK8kGL);
  numBytes += sLine_init(&sLine_d6g5m1uh);
  numBytes += sLine_init(&sLine_PPzwPZb1);
  numBytes += sLine_init(&sLine_UOhtJSe0);
  numBytes += sLine_init(&sLine_BzgbXKfX);
  numBytes += sLine_init(&sLine_S7cMoNSG);
  numBytes += sLine_init(&sLine_t3I1cexD);
  numBytes += sLine_init(&sLine_IqbIOaMP);
  numBytes += sLine_init(&sLine_hYZx748e);
  numBytes += sLine_init(&sLine_lETb5IG1);
  numBytes += sLine_init(&sLine_GuGVgj7U);
  numBytes += sLine_init(&sLine_NvzKyEBd);
  numBytes += sLine_init(&sLine_ttL8AaaY);
  numBytes += sLine_init(&sLine_DgQKzH8s);
  numBytes += sLine_init(&sLine_SITd45gn);
  numBytes += sLine_init(&sLine_R6E5LEgd);
  numBytes += sEnv_init(&sEnv_QImdAypF, 512, 256);
  numBytes += sEnv_init(&sEnv_EWNgFNwY, 512, 256);
  numBytes += sLine_init(&sLine_kVq9LUeB);
  numBytes += sLine_init(&sLine_LrL9CPCH);
  numBytes += sLine_init(&sLine_pVIQlwOl);
  numBytes += sLine_init(&sLine_bYxnjsfj);
  numBytes += sLine_init(&sLine_ZUqkRzHO);
  numBytes += sLine_init(&sLine_L01SeuM5);
  numBytes += sLine_init(&sLine_flgTNvt7);
  numBytes += sLine_init(&sLine_iK1pN3x2);
  numBytes += cVar_init_f(&cVar_En5e49RQ, 0.0f);
  numBytes += cVar_init_f(&cVar_blpAr6Fx, 0.0f);
  numBytes += cVar_init_f(&cVar_pbwm43QQ, 0.0f);
  numBytes += cVar_init_f(&cVar_LaE6xr3f, 0.0f);
  numBytes += cVar_init_f(&cVar_Xhp43NnP, 0.0f);
  numBytes += cVar_init_f(&cVar_gkjmkDor, 1.0f);
  numBytes += cVar_init_f(&cVar_PRuM8cl8, 0.0f);
  numBytes += cVar_init_f(&cVar_L7PiPclD, 0.0f);
  numBytes += cIf_init(&cIf_WiDUZRVL, false);
  numBytes += cIf_init(&cIf_Jm1YXacb, false);
  numBytes += cDelay_init(this, &cDelay_KED4XyaM, 10.0f);
  numBytes += cIf_init(&cIf_NiEJ09Kz, false);
  numBytes += cIf_init(&cIf_KM86fMXo, false);
  numBytes += cDelay_init(this, &cDelay_7JHakEB6, 10.0f);
  numBytes += cIf_init(&cIf_rSAbECU3, false);
  numBytes += cIf_init(&cIf_BL9LeLFS, false);
  numBytes += cDelay_init(this, &cDelay_B3Gb41C0, 10.0f);
  numBytes += cIf_init(&cIf_ci8BpZm3, false);
  numBytes += cIf_init(&cIf_IWM6LcgK, false);
  numBytes += cDelay_init(this, &cDelay_PcP1uLCX, 10.0f);
  numBytes += cIf_init(&cIf_OTDPbewU, false);
  numBytes += cIf_init(&cIf_o686E9De, false);
  numBytes += cDelay_init(this, &cDelay_Az2bs9tH, 10.0f);
  numBytes += cIf_init(&cIf_256PNUG7, false);
  numBytes += cIf_init(&cIf_25QViC09, false);
  numBytes += cDelay_init(this, &cDelay_xL4dxua7, 10.0f);
  numBytes += cIf_init(&cIf_7PtRxhMb, false);
  numBytes += cIf_init(&cIf_CsLslWc1, false);
  numBytes += cDelay_init(this, &cDelay_Q86HlJy7, 10.0f);
  numBytes += cIf_init(&cIf_euYJN051, false);
  numBytes += cIf_init(&cIf_ow6CofPp, false);
  numBytes += cDelay_init(this, &cDelay_cOnydjfl, 10.0f);
  numBytes += cIf_init(&cIf_7lSxrZUY, false);
  numBytes += cIf_init(&cIf_AoCrvea8, false);
  numBytes += cDelay_init(this, &cDelay_YLpZWJXe, 10.0f);
  numBytes += cIf_init(&cIf_z7nyvqlW, false);
  numBytes += cIf_init(&cIf_fy5lGSMQ, false);
  numBytes += cDelay_init(this, &cDelay_yX4wb0Sw, 10.0f);
  numBytes += cIf_init(&cIf_U4VooVIq, false);
  numBytes += cIf_init(&cIf_ppG3N2T3, false);
  numBytes += cDelay_init(this, &cDelay_lg8FXKhH, 10.0f);
  numBytes += cIf_init(&cIf_dscfBqtD, false);
  numBytes += cIf_init(&cIf_ZBdMawhn, false);
  numBytes += cDelay_init(this, &cDelay_N8ttpbUA, 10.0f);
  numBytes += sVarf_init(&sVarf_8XjiEgp0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NVDDVs3D, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RoECiHKO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2PVSYIHL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2RrpSq9x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DHRHQZNt, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EJDFkc19, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_02Pg92VY, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_4i5fYZFj, 0.0f);
  numBytes += cSlice_init(&cSlice_V4EKEQ6O, 1, -1);
  numBytes += cVar_init_f(&cVar_mSxIhTV1, 1.0f);
  numBytes += cSlice_init(&cSlice_Dif9OV9n, 1, -1);
  numBytes += cVar_init_f(&cVar_jI7ZH33A, 0.0f);
  numBytes += cSlice_init(&cSlice_YB56E76m, 1, -1);
  numBytes += cVar_init_f(&cVar_GNLQ9iQS, 512.0f);
  numBytes += cSlice_init(&cSlice_a8lI3nA7, 1, -1);
  numBytes += cVar_init_f(&cVar_TUeoXgkL, 1.0f);
  numBytes += cSlice_init(&cSlice_GDWw29PN, 1, -1);
  numBytes += cVar_init_f(&cVar_mQuOaVYA, 1.0f);
  numBytes += cDelay_init(this, &cDelay_3okuBU4O, 20.0f);
  numBytes += cVar_init_f(&cVar_HEjRNqk3, 0.0f);
  numBytes += cIf_init(&cIf_IMvZvH9x, false);
  numBytes += cIf_init(&cIf_9UVVq2co, false);
  numBytes += cBinop_init(&cBinop_ALpFKYtB, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_SpqKy5ZX, 1, -1);
  numBytes += cVar_init_f(&cVar_8n7yHsur, 0.0f);
  numBytes += sVarf_init(&sVarf_KHzI6wLs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2y4iqu3u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kMqRQs9k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6ZDKlb3O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iRA023Rq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_II8lJ8qw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3huzPwC4, 0.0f);
  numBytes += cVar_init_f(&cVar_MTypVfPU, 0.0f);
  numBytes += cIf_init(&cIf_PPzQRvyz, false);
  numBytes += cIf_init(&cIf_KWv2AcDX, false);
  numBytes += cDelay_init(this, &cDelay_llpQx1HR, 10.0f);
  numBytes += cIf_init(&cIf_ped1R0Cx, false);
  numBytes += cIf_init(&cIf_6t7r7ohM, false);
  numBytes += cDelay_init(this, &cDelay_sBXtyxAi, 10.0f);
  numBytes += cIf_init(&cIf_M9dnfl9P, false);
  numBytes += cIf_init(&cIf_DkGdK4je, false);
  numBytes += cDelay_init(this, &cDelay_sggvEQm6, 10.0f);
  numBytes += cIf_init(&cIf_fEHVDoHc, false);
  numBytes += cIf_init(&cIf_iIG8z9yt, false);
  numBytes += cDelay_init(this, &cDelay_wNGZRQ85, 10.0f);
  numBytes += cIf_init(&cIf_vsavgQ0D, false);
  numBytes += cIf_init(&cIf_8WxuceYn, false);
  numBytes += cDelay_init(this, &cDelay_lRj7wLaz, 10.0f);
  numBytes += cIf_init(&cIf_dCPL9VjR, false);
  numBytes += cIf_init(&cIf_y1NRpn7t, false);
  numBytes += cDelay_init(this, &cDelay_s9H8mruo, 10.0f);
  numBytes += cIf_init(&cIf_isQoYune, false);
  numBytes += cIf_init(&cIf_YjX4Eb9w, false);
  numBytes += cDelay_init(this, &cDelay_L3qJut1D, 10.0f);
  numBytes += cIf_init(&cIf_326pftmf, false);
  numBytes += cIf_init(&cIf_lpb9BCDg, false);
  numBytes += cDelay_init(this, &cDelay_hNXch6X4, 10.0f);
  numBytes += cIf_init(&cIf_TYCHs4j7, false);
  numBytes += cIf_init(&cIf_jbsFYARc, false);
  numBytes += cDelay_init(this, &cDelay_2hOEip7U, 10.0f);
  numBytes += cIf_init(&cIf_BnzmFduf, false);
  numBytes += cIf_init(&cIf_8vSEYaNz, false);
  numBytes += cDelay_init(this, &cDelay_f6kzetEp, 10.0f);
  numBytes += cIf_init(&cIf_CdHooQJs, false);
  numBytes += cIf_init(&cIf_2rAZ7eA9, false);
  numBytes += cDelay_init(this, &cDelay_UM5j3guS, 10.0f);
  numBytes += cIf_init(&cIf_Rilrslz6, false);
  numBytes += cIf_init(&cIf_zVDUrtc1, false);
  numBytes += cDelay_init(this, &cDelay_guEmzF4d, 10.0f);
  numBytes += sVarf_init(&sVarf_LaWHLmOD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kuYco5E5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mUrTflXh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vh3mZbhX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PhCT8Muq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6U2Jw3bo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fZcyKz6p, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5PpWaXzJ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PUf6eJ3T, 0.0f);
  numBytes += cSlice_init(&cSlice_AYjBUqu4, 1, -1);
  numBytes += cVar_init_f(&cVar_L1UYjPJ2, 1.0f);
  numBytes += cSlice_init(&cSlice_7bf8o5fz, 1, -1);
  numBytes += cVar_init_f(&cVar_pU8MdmVI, 0.0f);
  numBytes += cSlice_init(&cSlice_SeJ3ER0g, 1, -1);
  numBytes += cVar_init_f(&cVar_U8OI3DhF, 512.0f);
  numBytes += cSlice_init(&cSlice_43oipOrH, 1, -1);
  numBytes += cVar_init_f(&cVar_ACbcRTQZ, 1.0f);
  numBytes += cSlice_init(&cSlice_jXZ4ZJbD, 1, -1);
  numBytes += cVar_init_f(&cVar_7qzLFXf7, 1.0f);
  numBytes += cDelay_init(this, &cDelay_7HBM9dgZ, 20.0f);
  numBytes += cVar_init_f(&cVar_YCjk33GS, 0.0f);
  numBytes += cIf_init(&cIf_ajW4DVTm, false);
  numBytes += cIf_init(&cIf_FR7pgYfO, false);
  numBytes += cBinop_init(&cBinop_ols64H1e, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_6mGm0U5u, 1, -1);
  numBytes += cVar_init_f(&cVar_lhuw3fIM, 0.0f);
  numBytes += sVarf_init(&sVarf_8nfgyzJx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8ykUBkG2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KNSsClXp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6uwTpxkw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uoYELukh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v2n7U0Op, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FS3jEYjT, 0.0f);
  numBytes += sVarf_init(&sVarf_VrHYT66W, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kQCxbOPc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_R6NJ7rH4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_VfMpuEw0, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_MANGLR::~Heavy_WSTD_MANGLR() {
  sEnv_free(&sEnv_H7YTb8sx);
  sEnv_free(&sEnv_TFESkRSJ);
  sEnv_free(&sEnv_QImdAypF);
  sEnv_free(&sEnv_EWNgFNwY);
}

HvTable *Heavy_WSTD_MANGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_MANGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xE2DA4DC3: { // Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ymBAWkfk_sendMessage);
      break;
    }
    case 0xE42C892E: { // Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BSKUp0uP_sendMessage);
      break;
    }
    case 0x677821DA: { // Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_75yzm06f_sendMessage);
      break;
    }
    case 0xCB23DC60: { // Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DW9RFNHe_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bGqHv10U_sendMessage);
      break;
    }
    case 0xD88E26F9: { // Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tCCMFW09_sendMessage);
      break;
    }
    case 0x53F863DB: { // Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E77lo2FU_sendMessage);
      break;
    }
    case 0xCF8296B9: { // 1001-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cRLfsysc_sendMessage);
      break;
    }
    case 0x5F451395: { // 1021-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6dNGSs3f_sendMessage);
      break;
    }
    case 0xE57C8A1D: { // 1021-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JMxcAkm7_sendMessage);
      break;
    }
    case 0x67279E1E: { // 1021-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0rjgeTYv_sendMessage);
      break;
    }
    case 0x8CC7D86F: { // 1021-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rqap1zsf_sendMessage);
      break;
    }
    case 0xA88C638E: { // 1021-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9hMbRPGt_sendMessage);
      break;
    }
    case 0x15406E9F: { // 1021-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IL5oL3wH_sendMessage);
      break;
    }
    case 0x3C30F4E8: { // 1139-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hyHddeDg_sendMessage);
      break;
    }
    case 0xEF3938C5: { // 1139-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AiZotM6x_sendMessage);
      break;
    }
    case 0x416CCE3D: { // 1139-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pMmR5zFV_sendMessage);
      break;
    }
    case 0xA9746D8B: { // 1139-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XoxzzGzZ_sendMessage);
      break;
    }
    case 0x8DCB26C5: { // 1139-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R2woWGt5_sendMessage);
      break;
    }
    case 0x6EC228E5: { // 1139-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DusBExB8_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EQCYsFW0_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_MANGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Crshr";
        info->hash = 0xE2DA4DC3;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 1: {
        info->name = "Fldr";
        info->hash = 0xE42C892E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 2: {
        info->name = "Gain";
        info->hash = 0x677821DA;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -20.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Lmtr";
        info->hash = 0xCB23DC60;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 4: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 5: {
        info->name = "Smthr";
        info->hash = 0xD88E26F9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 6: {
        info->name = "Sqnc";
        info->hash = 0x53F863DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 7;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_MANGLR::cVar_En5e49RQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n06vLOEi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_JTWgeGDp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_jDSqbDFP_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jDSqbDFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_8YEk0njX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8YEk0njX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_GropFVbO_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_GropFVbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_50Cmp9yc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JoCleuhV_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JoCleuhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_whwD4ChO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_50Cmp9yc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_5QIMjxjN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5QIMjxjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_miILum80_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_whwD4ChO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4VOxZU9d_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4VOxZU9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Ji4lk8V5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_miILum80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5Wl3MPF0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_Ji4lk8V5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YeQSLYkz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_blpAr6Fx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_23yPFRU2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_pbwm43QQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vqyLxUOX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_LaE6xr3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5VcXYvE7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_Xhp43NnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GxPafQem_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_gkjmkDor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rqRZQSIb_sendMessage);
  cMsg_KLSzm3k0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cBinop_rqRZQSIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gkjmkDor, 1, m, &cVar_gkjmkDor_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_LA2b11BP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qEWiF8bK_sendMessage(_c, 0, m);
  cMsg_ofhwRpdN_sendMessage(_c, 0, m);
  cMsg_xHWf0cTH_sendMessage(_c, 0, m);
  cMsg_kVY6SkOH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_PRuM8cl8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zTU6GXV1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_L7PiPclD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FmTrS5qt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_1URAECSm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QzNAzUw2_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IgPW45jS_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Bpf5NiXu_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8IzKuNeQ_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2XhnnJ0m_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7GZCqMF2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_QzNAzUw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NXY9P0I0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_IgPW45jS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Alb3JvaB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Bpf5NiXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ldr0BLuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_8IzKuNeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yxHWPS2M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_2XhnnJ0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N4A9TZw8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_7GZCqMF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j4zN6X4b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_WiDUZRVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GYLU28Gf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_Jm1YXacb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kkJlyhoQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_bmXYw0Aj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rTeoDoTC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rTeoDoTC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KED4XyaM, 1, m, &cDelay_KED4XyaM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c51EPA97_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_KED4XyaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KED4XyaM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_WiDUZRVL, 0, m, &cIf_WiDUZRVL_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rTeoDoTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KED4XyaM, 0, m, &cDelay_KED4XyaM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_c51EPA97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KED4XyaM, 0, m, &cDelay_KED4XyaM_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rPY786TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JqFZhUvC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pSIaqLYa_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_1FQBbFHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5uuWTB1y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4YO1wV99_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5uuWTB1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WiDUZRVL, 1, m, &cIf_WiDUZRVL_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_4YO1wV99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bmXYw0Aj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_JqFZhUvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jm1YXacb, 1, m, &cIf_Jm1YXacb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pSIaqLYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jm1YXacb, 0, m, &cIf_Jm1YXacb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kkJlyhoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C2bPcCay, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GYLU28Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C2bPcCay, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_NiEJ09Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oyzYAiyZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_KM86fMXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Yybwah4R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_x6XvrE0R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EgIN74GD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EgIN74GD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7JHakEB6, 1, m, &cDelay_7JHakEB6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nmCUxTvz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7JHakEB6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7JHakEB6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NiEJ09Kz, 0, m, &cIf_NiEJ09Kz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EgIN74GD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7JHakEB6, 0, m, &cDelay_7JHakEB6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nmCUxTvz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7JHakEB6, 0, m, &cDelay_7JHakEB6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qteGiY2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mzqbxUYH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8RXZBsQ5_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xqW1GlTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TEwSqYyE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IdmWq0JQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_TEwSqYyE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NiEJ09Kz, 1, m, &cIf_NiEJ09Kz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_IdmWq0JQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x6XvrE0R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_mzqbxUYH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KM86fMXo, 1, m, &cIf_KM86fMXo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_8RXZBsQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KM86fMXo, 0, m, &cIf_KM86fMXo_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Yybwah4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RQtLcHpg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_oyzYAiyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RQtLcHpg, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_rSAbECU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BvLeo5bu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_BL9LeLFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OLGdFGjk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_heWDD1PR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Y4bv7g1a_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Y4bv7g1a_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B3Gb41C0, 1, m, &cDelay_B3Gb41C0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_70oi7q5x_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_B3Gb41C0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B3Gb41C0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rSAbECU3, 0, m, &cIf_rSAbECU3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Y4bv7g1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B3Gb41C0, 0, m, &cDelay_B3Gb41C0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_70oi7q5x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B3Gb41C0, 0, m, &cDelay_B3Gb41C0_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3Bu18oHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W1PwK5Nj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FGaxCVSS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hBGmthC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CABxv5l8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UqvSOYJs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CABxv5l8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rSAbECU3, 1, m, &cIf_rSAbECU3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UqvSOYJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_heWDD1PR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_W1PwK5Nj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BL9LeLFS, 1, m, &cIf_BL9LeLFS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FGaxCVSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BL9LeLFS, 0, m, &cIf_BL9LeLFS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_OLGdFGjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7oqO1iEt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_BvLeo5bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7oqO1iEt, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ci8BpZm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_04bnDI6j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_IWM6LcgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dXqHkMBE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_sghHpzzz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Eym4v5Yh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Eym4v5Yh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PcP1uLCX, 1, m, &cDelay_PcP1uLCX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kfZSqSRH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_PcP1uLCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PcP1uLCX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ci8BpZm3, 0, m, &cIf_ci8BpZm3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Eym4v5Yh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PcP1uLCX, 0, m, &cDelay_PcP1uLCX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kfZSqSRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PcP1uLCX, 0, m, &cDelay_PcP1uLCX_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_OrfZ3EOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rgh21G9O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5QZaa2hj_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rut52QA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kcjG8swG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eugCdvt4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eugCdvt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sghHpzzz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_kcjG8swG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ci8BpZm3, 1, m, &cIf_ci8BpZm3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rgh21G9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IWM6LcgK, 1, m, &cIf_IWM6LcgK_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5QZaa2hj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IWM6LcgK, 0, m, &cIf_IWM6LcgK_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dXqHkMBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WW7ak4vb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_04bnDI6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WW7ak4vb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_OTDPbewU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ys0OEkqk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_o686E9De_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cPsdUByX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_qsonI4Xe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Ak8EYYwM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Ak8EYYwM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Az2bs9tH, 1, m, &cDelay_Az2bs9tH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ACWgEHzS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Az2bs9tH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Az2bs9tH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OTDPbewU, 0, m, &cIf_OTDPbewU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Ak8EYYwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Az2bs9tH, 0, m, &cDelay_Az2bs9tH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ACWgEHzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Az2bs9tH, 0, m, &cDelay_Az2bs9tH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_inbD5252_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JkBRnzFD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WhhmJ86u_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KenXcDnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A5ZPF5eI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UbdRvUJz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UbdRvUJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qsonI4Xe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_A5ZPF5eI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OTDPbewU, 1, m, &cIf_OTDPbewU_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WhhmJ86u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o686E9De, 0, m, &cIf_o686E9De_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_JkBRnzFD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o686E9De, 1, m, &cIf_o686E9De_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cPsdUByX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pd3omEAd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ys0OEkqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pd3omEAd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_256PNUG7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r5cGr2eC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_25QViC09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oWcXAksM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_8BC1AU40_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XSwixHQL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XSwixHQL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xL4dxua7, 1, m, &cDelay_xL4dxua7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OKRtDdd5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_xL4dxua7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xL4dxua7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_256PNUG7, 0, m, &cIf_256PNUG7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_XSwixHQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xL4dxua7, 0, m, &cDelay_xL4dxua7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OKRtDdd5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xL4dxua7, 0, m, &cDelay_xL4dxua7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_wwmJfpVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_udn9nsQ6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kinRYfyQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_abbrPaVa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XaxR5STq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tT0kxRC0_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_tT0kxRC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8BC1AU40_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_XaxR5STq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_256PNUG7, 1, m, &cIf_256PNUG7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_kinRYfyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_25QViC09, 0, m, &cIf_25QViC09_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_udn9nsQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_25QViC09, 1, m, &cIf_25QViC09_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oWcXAksM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Az7lmNHU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_r5cGr2eC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Az7lmNHU, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7PtRxhMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jnNzZMyq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_CsLslWc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lzMd830N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_rvYbSy1c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_25MNE9FG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_25MNE9FG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Q86HlJy7, 1, m, &cDelay_Q86HlJy7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wLhVzJVv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_Q86HlJy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Q86HlJy7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7PtRxhMb, 0, m, &cIf_7PtRxhMb_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_25MNE9FG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q86HlJy7, 0, m, &cDelay_Q86HlJy7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_wLhVzJVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Q86HlJy7, 0, m, &cDelay_Q86HlJy7_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_xAG3uXgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xzapFY3j_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rznvoh3m_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_KEzk3brU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQOJnyH9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VV2OLaua_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VV2OLaua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rvYbSy1c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hQOJnyH9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7PtRxhMb, 1, m, &cIf_7PtRxhMb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rznvoh3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CsLslWc1, 0, m, &cIf_CsLslWc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xzapFY3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CsLslWc1, 1, m, &cIf_CsLslWc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_lzMd830N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KIP3Sycb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_jnNzZMyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KIP3Sycb, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_euYJN051_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yFWlY4rd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ow6CofPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1hHuLUuW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_LEm6yGV5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Wo4ULWVh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Wo4ULWVh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cOnydjfl, 1, m, &cDelay_cOnydjfl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QEwFbUTE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_cOnydjfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cOnydjfl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_euYJN051, 0, m, &cIf_euYJN051_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Wo4ULWVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOnydjfl, 0, m, &cDelay_cOnydjfl_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QEwFbUTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOnydjfl, 0, m, &cDelay_cOnydjfl_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UNdNvvKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9ExaVeU2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O3lAsrL3_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_rk85D6Kl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Rg87Rsr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yrEj3p5J_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_5Rg87Rsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_euYJN051, 1, m, &cIf_euYJN051_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_yrEj3p5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LEm6yGV5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_9ExaVeU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ow6CofPp, 1, m, &cIf_ow6CofPp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_O3lAsrL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ow6CofPp, 0, m, &cIf_ow6CofPp_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1hHuLUuW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E352qLFW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_yFWlY4rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_E352qLFW, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_7lSxrZUY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vTbiVs18_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_AoCrvea8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rhjimm31_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_cjCLtrDM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g3HdaGzO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g3HdaGzO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YLpZWJXe, 1, m, &cDelay_YLpZWJXe_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1pM91fng_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_YLpZWJXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YLpZWJXe, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7lSxrZUY, 0, m, &cIf_7lSxrZUY_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_g3HdaGzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YLpZWJXe, 0, m, &cDelay_YLpZWJXe_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1pM91fng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YLpZWJXe, 0, m, &cDelay_YLpZWJXe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yTwqEYPE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O9RAK24n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PVHPIkiY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_54Y2yOFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qc7FMNGc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1mrbWpj4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qc7FMNGc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7lSxrZUY, 1, m, &cIf_7lSxrZUY_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_1mrbWpj4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cjCLtrDM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_O9RAK24n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AoCrvea8, 1, m, &cIf_AoCrvea8_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_PVHPIkiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AoCrvea8, 0, m, &cIf_AoCrvea8_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rhjimm31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_53zPH6kP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_vTbiVs18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_53zPH6kP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_z7nyvqlW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_QEL2ySLp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_fy5lGSMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EhDTLTSS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ebGEmA4L_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_K7OKU9Od_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_K7OKU9Od_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_yX4wb0Sw, 1, m, &cDelay_yX4wb0Sw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uRquMha2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_yX4wb0Sw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_yX4wb0Sw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_z7nyvqlW, 0, m, &cIf_z7nyvqlW_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_K7OKU9Od_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_yX4wb0Sw, 0, m, &cDelay_yX4wb0Sw_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_uRquMha2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_yX4wb0Sw, 0, m, &cDelay_yX4wb0Sw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_hHxMlgQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qjUwZo1r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nLunlF8z_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_mKK5zsxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hznjXeab_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3XA6TJms_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3XA6TJms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ebGEmA4L_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_hznjXeab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_z7nyvqlW, 1, m, &cIf_z7nyvqlW_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nLunlF8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fy5lGSMQ, 0, m, &cIf_fy5lGSMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qjUwZo1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fy5lGSMQ, 1, m, &cIf_fy5lGSMQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EhDTLTSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jzsdNaYm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_QEL2ySLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jzsdNaYm, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_U4VooVIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cQMGbkbQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ppG3N2T3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ix0kQDWX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_zM7jtVq9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hvXyk6gZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hvXyk6gZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lg8FXKhH, 1, m, &cDelay_lg8FXKhH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_617vxmj6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lg8FXKhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lg8FXKhH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_U4VooVIq, 0, m, &cIf_U4VooVIq_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hvXyk6gZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lg8FXKhH, 0, m, &cDelay_lg8FXKhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_617vxmj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lg8FXKhH, 0, m, &cDelay_lg8FXKhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_jreLe1y0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkgjYRmH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m3zOnn4U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TqUPhcUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DLxHyDQF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X7gWuolJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_DLxHyDQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U4VooVIq, 1, m, &cIf_U4VooVIq_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X7gWuolJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zM7jtVq9_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_XkgjYRmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ppG3N2T3, 1, m, &cIf_ppG3N2T3_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_m3zOnn4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ppG3N2T3, 0, m, &cIf_ppG3N2T3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ix0kQDWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nCkqt59U, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_cQMGbkbQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nCkqt59U, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_dscfBqtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W0NFDWKr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_ZBdMawhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hLEV3gY3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_6xa2M1iv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IZlh42GT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IZlh42GT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_N8ttpbUA, 1, m, &cDelay_N8ttpbUA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Gw5rqF6o_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_N8ttpbUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_N8ttpbUA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dscfBqtD, 0, m, &cIf_dscfBqtD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IZlh42GT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_N8ttpbUA, 0, m, &cDelay_N8ttpbUA_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Gw5rqF6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_N8ttpbUA, 0, m, &cDelay_N8ttpbUA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_CTPMcNL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_taZb51Af_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I5MzCW2S_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_TFa4rSvN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z7wJLLW7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_plOVr7rb_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_plOVr7rb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6xa2M1iv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_z7wJLLW7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dscfBqtD, 1, m, &cIf_dscfBqtD_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_taZb51Af_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZBdMawhn, 1, m, &cIf_ZBdMawhn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_I5MzCW2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZBdMawhn, 0, m, &cIf_ZBdMawhn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hLEV3gY3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jF0Y2asR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_W0NFDWKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jF0Y2asR, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_NXY9P0I0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_BVR4gIpf_sendMessage(_c, 0, m);
  cMsg_VxTGj3Ko_sendMessage(_c, 0, m);
  cMsg_vxhhOOKq_sendMessage(_c, 0, m);
  cMsg_7O72BfKf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Alb3JvaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_BVR4gIpf_sendMessage(_c, 0, m);
  cMsg_B4kmFF7O_sendMessage(_c, 0, m);
  cMsg_NkgIMhAy_sendMessage(_c, 0, m);
  cMsg_jDpEIG8g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ldr0BLuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_LagQv5fR_sendMessage(_c, 0, m);
  cMsg_B4kmFF7O_sendMessage(_c, 0, m);
  cMsg_7O72BfKf_sendMessage(_c, 0, m);
  cMsg_SCogZQnd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_yxHWPS2M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_LagQv5fR_sendMessage(_c, 0, m);
  cMsg_Qh6snOSR_sendMessage(_c, 0, m);
  cMsg_vxhhOOKq_sendMessage(_c, 0, m);
  cMsg_B4RzEZyu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_N4A9TZw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_RDFYByyl_sendMessage(_c, 0, m);
  cMsg_jDpEIG8g_sendMessage(_c, 0, m);
  cMsg_7t5prrqp_sendMessage(_c, 0, m);
  cMsg_vxhhOOKq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_j4zN6X4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_RDFYByyl_sendMessage(_c, 0, m);
  cMsg_B4RzEZyu_sendMessage(_c, 0, m);
  cMsg_B4kmFF7O_sendMessage(_c, 0, m);
  cMsg_KtAamJMo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_9PfSpQqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1FQBbFHQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rPY786TS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_No3efkEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1FQBbFHQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rPY786TS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WBzYfMGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xqW1GlTg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qteGiY2d_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L6xCuRs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xqW1GlTg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qteGiY2d_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZSOXPWMH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBGmthC8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3Bu18oHA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vkWE4KHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_hBGmthC8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3Bu18oHA_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_BVR4gIpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_9PfSpQqK_sendMessage(_c, 0, m);
  cMsg_L6xCuRs6_sendMessage(_c, 0, m);
  cMsg_vkWE4KHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_LagQv5fR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_No3efkEh_sendMessage(_c, 0, m);
  cMsg_WBzYfMGL_sendMessage(_c, 0, m);
  cMsg_vkWE4KHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_RDFYByyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_No3efkEh_sendMessage(_c, 0, m);
  cMsg_L6xCuRs6_sendMessage(_c, 0, m);
  cMsg_ZSOXPWMH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Q5HEzuEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rut52QA0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OrfZ3EOJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SfONNcCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rut52QA0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OrfZ3EOJ_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_biaGuuip_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KenXcDnj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_inbD5252_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yrEbpUKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KenXcDnj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_inbD5252_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ysyMv2j2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_abbrPaVa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wwmJfpVX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_X715amrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_abbrPaVa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wwmJfpVX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_B4kmFF7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_SfONNcCh_sendMessage(_c, 0, m);
  cMsg_yrEbpUKs_sendMessage(_c, 0, m);
  cMsg_X715amrW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_VxTGj3Ko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_SfONNcCh_sendMessage(_c, 0, m);
  cMsg_biaGuuip_sendMessage(_c, 0, m);
  cMsg_ysyMv2j2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Qh6snOSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_Q5HEzuEX_sendMessage(_c, 0, m);
  cMsg_yrEbpUKs_sendMessage(_c, 0, m);
  cMsg_ysyMv2j2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_NxpqUzFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mKK5zsxq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hHxMlgQ1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8ZzrPNe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mKK5zsxq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_hHxMlgQ1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_GFHqNjJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TqUPhcUy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jreLe1y0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_SMg3BVMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TqUPhcUy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jreLe1y0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wI7EfUrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TFa4rSvN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CTPMcNL0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DBuNgZyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TFa4rSvN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CTPMcNL0_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_B4RzEZyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_NxpqUzFn_sendMessage(_c, 0, m);
  cMsg_SMg3BVMQ_sendMessage(_c, 0, m);
  cMsg_DBuNgZyz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jDpEIG8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_8ZzrPNe6_sendMessage(_c, 0, m);
  cMsg_GFHqNjJF_sendMessage(_c, 0, m);
  cMsg_DBuNgZyz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7O72BfKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_8ZzrPNe6_sendMessage(_c, 0, m);
  cMsg_SMg3BVMQ_sendMessage(_c, 0, m);
  cMsg_wI7EfUrA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_1lE4lAxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KEzk3brU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xAG3uXgT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ZA13s01f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KEzk3brU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xAG3uXgT_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_i8nha4cZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rk85D6Kl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UNdNvvKd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_LeGQiZYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rk85D6Kl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UNdNvvKd_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8hieoj05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_54Y2yOFz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yTwqEYPE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FAYZBrGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_54Y2yOFz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yTwqEYPE_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vxhhOOKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ZA13s01f_sendMessage(_c, 0, m);
  cMsg_LeGQiZYy_sendMessage(_c, 0, m);
  cMsg_FAYZBrGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_NkgIMhAy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ZA13s01f_sendMessage(_c, 0, m);
  cMsg_i8nha4cZ_sendMessage(_c, 0, m);
  cMsg_8hieoj05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_KtAamJMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_1lE4lAxj_sendMessage(_c, 0, m);
  cMsg_i8nha4cZ_sendMessage(_c, 0, m);
  cMsg_FAYZBrGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_7t5prrqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_Q5HEzuEX_sendMessage(_c, 0, m);
  cMsg_biaGuuip_sendMessage(_c, 0, m);
  cMsg_X715amrW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_SCogZQnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_1lE4lAxj_sendMessage(_c, 0, m);
  cMsg_LeGQiZYy_sendMessage(_c, 0, m);
  cMsg_8hieoj05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_4i5fYZFj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0EU6AwRV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_BSxyMGyW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V4EKEQ6O, 0, m, &cSlice_V4EKEQ6O_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vTT2mXS7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_V4EKEQ6O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CTLx5jik_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CTLx5jik_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_mSxIhTV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CTLx5jik_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_CTLx5jik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JMxcAkm7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_ikJt04rK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Dif9OV9n, 0, m, &cSlice_Dif9OV9n_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VoePi0cl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_Dif9OV9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_y2RAjHf9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_y2RAjHf9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_jI7ZH33A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y2RAjHf9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_y2RAjHf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IL5oL3wH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_VoePi0cl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YB56E76m, 0, m, &cSlice_YB56E76m_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BSxyMGyW_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_YB56E76m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_q3j1pDJt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_q3j1pDJt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_GNLQ9iQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_q3j1pDJt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_q3j1pDJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6dNGSs3f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_vTT2mXS7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_a8lI3nA7, 0, m, &cSlice_a8lI3nA7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bbHieaYk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_a8lI3nA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_43Q1HOPo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_43Q1HOPo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_TUeoXgkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_43Q1HOPo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_43Q1HOPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9hMbRPGt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_bbHieaYk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GDWw29PN, 0, m, &cSlice_GDWw29PN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jLTfx8it_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_GDWw29PN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0pMUIvNs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0pMUIvNs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_mQuOaVYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0pMUIvNs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_0pMUIvNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rqap1zsf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_LPFfxy82_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0HxQchO7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0HxQchO7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_3okuBU4O, 1, m, &cDelay_3okuBU4O_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6bq6QQVL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_3okuBU4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_3okuBU4O, m);
  cMsg_hMATduqd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_0HxQchO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_3okuBU4O, 0, m, &cDelay_3okuBU4O_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_6bq6QQVL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_3okuBU4O, 0, m, &cDelay_3okuBU4O_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_HEjRNqk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ALpFKYtB, HV_BINOP_SUBTRACT, 0, m, &cBinop_ALpFKYtB_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_IMvZvH9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L9E19BSA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_9UVVq2co_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L9E19BSA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_H7YTb8sx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HEjRNqk3, 0, m, &cVar_HEjRNqk3_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_TFESkRSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nRtw1YMc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zWQBKEsL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4piWUTlr_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ALpFKYtB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AD5VjtM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_AD5VjtM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UeflP7pA_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_UeflP7pA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Jgg7kAIw_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_qQbra6Tl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1rug4fge_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HXq0YwHQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HXq0YwHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1y0V0GQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_1rug4fge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IMvZvH9x, 1, m, &cIf_IMvZvH9x_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_4azfOEQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9UVVq2co, 1, m, &cIf_9UVVq2co_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_1y0V0GQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_IMvZvH9x, 0, m, &cIf_IMvZvH9x_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Jgg7kAIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9UVVq2co, 0, m, &cIf_9UVVq2co_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_zWQBKEsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ALpFKYtB, HV_BINOP_SUBTRACT, 1, m, &cBinop_ALpFKYtB_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_nRtw1YMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_4piWUTlr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HEjRNqk3, 0, m, &cVar_HEjRNqk3_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L9E19BSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Sjs09Sbn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_jLTfx8it_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SpqKy5ZX, 0, m, &cSlice_SpqKy5ZX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_SpqKy5ZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_58y3laac_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_58y3laac_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_8n7yHsur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_58y3laac_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_58y3laac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0rjgeTYv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zTU6GXV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UOhtJSe0, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_FmTrS5qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_d6g5m1uh, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_BPqBhXXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L7PiPclD, 0, m, &cVar_L7PiPclD_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0EU6AwRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PPzwPZb1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_8jncoog1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oyybR0TC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_L0adq96C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LPFfxy82_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_hMATduqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ild1tk0M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_oyybR0TC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ild1tk0M, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KPP8Il8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_nWATq0jY_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_nWATq0jY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oO8LrY78_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_oO8LrY78_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KhzK8kGL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_3huzPwC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fwHbN8xX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_MTypVfPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fRs7RE8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_3gnidjrY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QyfAYDz6_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tvm4qvBz_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nM5tCNW1_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XhrlUn8Z_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0a1GfVzO_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rChOEXl2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cCast_QyfAYDz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_akD7ABTK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_Tvm4qvBz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5xVifGEo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_nM5tCNW1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zi0QNVoV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_XhrlUn8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T2eAuBkx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_0a1GfVzO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Qz42DjJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_rChOEXl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XgCFVtmv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cIf_PPzQRvyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_apmgdUDi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_KWv2AcDX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_C3I83wVE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_aFYIOg2h_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hcQzu7ei_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hcQzu7ei_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_llpQx1HR, 1, m, &cDelay_llpQx1HR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aCIW54JS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_llpQx1HR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_llpQx1HR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PPzQRvyz, 0, m, &cIf_PPzQRvyz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_hcQzu7ei_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_llpQx1HR, 0, m, &cDelay_llpQx1HR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aCIW54JS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_llpQx1HR, 0, m, &cDelay_llpQx1HR_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_74S6PjQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ywyhV7Mr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Yq3tzJu_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_R8gomU33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fzOG7Z6i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_INCnZH6J_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_INCnZH6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_aFYIOg2h_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_fzOG7Z6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PPzQRvyz, 1, m, &cIf_PPzQRvyz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2Yq3tzJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KWv2AcDX, 0, m, &cIf_KWv2AcDX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ywyhV7Mr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KWv2AcDX, 1, m, &cIf_KWv2AcDX_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_C3I83wVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IqbIOaMP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_apmgdUDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IqbIOaMP, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_ped1R0Cx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PWGgG5xP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_6t7r7ohM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rjDh6RWm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_Rx03boMn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MS3JWAse_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MS3JWAse_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sBXtyxAi, 1, m, &cDelay_sBXtyxAi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jrAVBmsC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_sBXtyxAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sBXtyxAi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ped1R0Cx, 0, m, &cIf_ped1R0Cx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_MS3JWAse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sBXtyxAi, 0, m, &cDelay_sBXtyxAi_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jrAVBmsC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sBXtyxAi, 0, m, &cDelay_sBXtyxAi_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_x4HZq0t6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GqCRvNRC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2R1SiYhB_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8NTL4iXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rHgNttpD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K7rdQsam_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_K7rdQsam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Rx03boMn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_rHgNttpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ped1R0Cx, 1, m, &cIf_ped1R0Cx_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_2R1SiYhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6t7r7ohM, 0, m, &cIf_6t7r7ohM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GqCRvNRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6t7r7ohM, 1, m, &cIf_6t7r7ohM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rjDh6RWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GuGVgj7U, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_PWGgG5xP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GuGVgj7U, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_M9dnfl9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_n8B9Eorl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_DkGdK4je_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Sl0YGxGX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_hRY3pLEc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_PhyKbRfm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_PhyKbRfm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sggvEQm6, 1, m, &cDelay_sggvEQm6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QQRmyINW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_sggvEQm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sggvEQm6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_M9dnfl9P, 0, m, &cIf_M9dnfl9P_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_PhyKbRfm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sggvEQm6, 0, m, &cDelay_sggvEQm6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_QQRmyINW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sggvEQm6, 0, m, &cDelay_sggvEQm6_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_DEGrO4St_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FC4TQvkz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WGlJrf1F_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_y7Sb8wqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tDeTKiYc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gq9YbaFh_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gq9YbaFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hRY3pLEc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_tDeTKiYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M9dnfl9P, 1, m, &cIf_M9dnfl9P_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_WGlJrf1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DkGdK4je, 0, m, &cIf_DkGdK4je_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FC4TQvkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DkGdK4je, 1, m, &cIf_DkGdK4je_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Sl0YGxGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DgQKzH8s, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_n8B9Eorl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DgQKzH8s, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_fEHVDoHc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_91aohLvR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_iIG8z9yt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_L5xB48E5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_vcvUhHpl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eekmRhHZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eekmRhHZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_wNGZRQ85, 1, m, &cDelay_wNGZRQ85_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HPwVH8fp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_wNGZRQ85_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wNGZRQ85, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fEHVDoHc, 0, m, &cIf_fEHVDoHc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eekmRhHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_wNGZRQ85, 0, m, &cDelay_wNGZRQ85_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HPwVH8fp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_wNGZRQ85, 0, m, &cDelay_wNGZRQ85_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_eWJ4Di6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9H3JebjP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j8lSoX72_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_sEV6MwhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gaHnCwtV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_asGxHcOH_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_gaHnCwtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fEHVDoHc, 1, m, &cIf_fEHVDoHc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_asGxHcOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vcvUhHpl_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_j8lSoX72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iIG8z9yt, 0, m, &cIf_iIG8z9yt_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_9H3JebjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iIG8z9yt, 1, m, &cIf_iIG8z9yt_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_L5xB48E5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hYZx748e, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_91aohLvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hYZx748e, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_vsavgQ0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MYcLNsFZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_8WxuceYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kOkXv0Pe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_x2oA0NwO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pMAln3K8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pMAln3K8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_lRj7wLaz, 1, m, &cDelay_lRj7wLaz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xkHV5J3y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_lRj7wLaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_lRj7wLaz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vsavgQ0D, 0, m, &cIf_vsavgQ0D_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_pMAln3K8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_lRj7wLaz, 0, m, &cDelay_lRj7wLaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_xkHV5J3y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_lRj7wLaz, 0, m, &cDelay_lRj7wLaz_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_YkDUOvMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9q4F1kAc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p2J63SF1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yTLacEJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_39hKwaA9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CCIYMOId_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_39hKwaA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vsavgQ0D, 1, m, &cIf_vsavgQ0D_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_CCIYMOId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x2oA0NwO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_9q4F1kAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8WxuceYn, 1, m, &cIf_8WxuceYn_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_p2J63SF1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8WxuceYn, 0, m, &cIf_8WxuceYn_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_kOkXv0Pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NvzKyEBd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_MYcLNsFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NvzKyEBd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_dCPL9VjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eCtR5I99_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_y1NRpn7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IGmso5pf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_geRgGBez_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_dAAZjeI6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_dAAZjeI6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_s9H8mruo, 1, m, &cDelay_s9H8mruo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P3EVfBVI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_s9H8mruo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s9H8mruo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dCPL9VjR, 0, m, &cIf_dCPL9VjR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_dAAZjeI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_s9H8mruo, 0, m, &cDelay_s9H8mruo_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_P3EVfBVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s9H8mruo, 0, m, &cDelay_s9H8mruo_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_37paZZiS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wjcRuY87_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p52cuLGe_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_iI1ovW82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pbPXQHWr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Qz0JdM72_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_pbPXQHWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dCPL9VjR, 1, m, &cIf_dCPL9VjR_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Qz0JdM72_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_geRgGBez_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_wjcRuY87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y1NRpn7t, 1, m, &cIf_y1NRpn7t_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_p52cuLGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_y1NRpn7t, 0, m, &cIf_y1NRpn7t_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_IGmso5pf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SITd45gn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_eCtR5I99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SITd45gn, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_isQoYune_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8sHranL0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_YjX4Eb9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b9nxt4D3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_ToBTk2fd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wOmk2SzW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wOmk2SzW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_L3qJut1D, 1, m, &cDelay_L3qJut1D_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rVIhhFOJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_L3qJut1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_L3qJut1D, m);
  cIf_onMessage(_c, &Context(_c)->cIf_isQoYune, 0, m, &cIf_isQoYune_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wOmk2SzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_L3qJut1D, 0, m, &cDelay_L3qJut1D_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rVIhhFOJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_L3qJut1D, 0, m, &cDelay_L3qJut1D_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_XDptWZGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T23ez4PD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KWyTMQk1_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_RodfGRjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jYaHiZbR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NItFWudf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_NItFWudf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ToBTk2fd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_jYaHiZbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_isQoYune, 1, m, &cIf_isQoYune_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_KWyTMQk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YjX4Eb9w, 0, m, &cIf_YjX4Eb9w_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_T23ez4PD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YjX4Eb9w, 1, m, &cIf_YjX4Eb9w_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_b9nxt4D3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lETb5IG1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_8sHranL0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lETb5IG1, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_326pftmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ov8Pd0d0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_lpb9BCDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_a0L9O8rK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_SHlFsfsb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0f2HMEFq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0f2HMEFq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hNXch6X4, 1, m, &cDelay_hNXch6X4_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X8dbu2kK_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_hNXch6X4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hNXch6X4, m);
  cIf_onMessage(_c, &Context(_c)->cIf_326pftmf, 0, m, &cIf_326pftmf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0f2HMEFq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hNXch6X4, 0, m, &cDelay_hNXch6X4_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_X8dbu2kK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hNXch6X4, 0, m, &cDelay_hNXch6X4_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_er2ad3NM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v2TXZgJY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NV1swqLs_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_3dCJeADb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_etTHy2Eb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AuMi7uhM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_etTHy2Eb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_326pftmf, 1, m, &cIf_326pftmf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_AuMi7uhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SHlFsfsb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_NV1swqLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lpb9BCDg, 0, m, &cIf_lpb9BCDg_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_v2TXZgJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lpb9BCDg, 1, m, &cIf_lpb9BCDg_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_a0L9O8rK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ttL8AaaY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_Ov8Pd0d0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ttL8AaaY, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_TYCHs4j7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_b9Icdwyk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_jbsFYARc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Up0nd9Pb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_PAbUD6Ys_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Jq479oMm_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Jq479oMm_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2hOEip7U, 1, m, &cDelay_2hOEip7U_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ms0rTFoq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_2hOEip7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2hOEip7U, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TYCHs4j7, 0, m, &cIf_TYCHs4j7_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Jq479oMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2hOEip7U, 0, m, &cDelay_2hOEip7U_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ms0rTFoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2hOEip7U, 0, m, &cDelay_2hOEip7U_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_L5DH9B2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IgKlcSrF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HukhVB2X_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_uFCdul2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OhIkKGHf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jMiKaO7B_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_OhIkKGHf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TYCHs4j7, 1, m, &cIf_TYCHs4j7_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_jMiKaO7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PAbUD6Ys_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_IgKlcSrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jbsFYARc, 1, m, &cIf_jbsFYARc_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_HukhVB2X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jbsFYARc, 0, m, &cIf_jbsFYARc_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Up0nd9Pb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R6E5LEgd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_b9Icdwyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R6E5LEgd, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_BnzmFduf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KumqTbxd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_8vSEYaNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Vce5rR6R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_hSXyczwM_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_c4DUK9Hk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_c4DUK9Hk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_f6kzetEp, 1, m, &cDelay_f6kzetEp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aKCnzAbC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_f6kzetEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_f6kzetEp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_BnzmFduf, 0, m, &cIf_BnzmFduf_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_c4DUK9Hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_f6kzetEp, 0, m, &cDelay_f6kzetEp_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_aKCnzAbC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_f6kzetEp, 0, m, &cDelay_f6kzetEp_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_8HXFiBP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yYTGJUzo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FdbtOeeE_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_6rDooRNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UswkGUMt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eMlrqtaM_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_UswkGUMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BnzmFduf, 1, m, &cIf_BnzmFduf_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_eMlrqtaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hSXyczwM_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_yYTGJUzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vSEYaNz, 1, m, &cIf_8vSEYaNz_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FdbtOeeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8vSEYaNz, 0, m, &cIf_8vSEYaNz_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Vce5rR6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BzgbXKfX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KumqTbxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BzgbXKfX, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_CdHooQJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rfkMAiCz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_2rAZ7eA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rOaAPNAV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_kZJJI26c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fzGQPgOj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fzGQPgOj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UM5j3guS, 1, m, &cDelay_UM5j3guS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cey4ItMu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_UM5j3guS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UM5j3guS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CdHooQJs, 0, m, &cIf_CdHooQJs_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_fzGQPgOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UM5j3guS, 0, m, &cDelay_UM5j3guS_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_cey4ItMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UM5j3guS, 0, m, &cDelay_UM5j3guS_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_gGVkVGhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_30fb79AW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FVKIxH6w_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_AJob8Akl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zjBoeYCZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qwEtN7xI_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_qwEtN7xI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kZJJI26c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_zjBoeYCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CdHooQJs, 1, m, &cIf_CdHooQJs_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_30fb79AW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2rAZ7eA9, 1, m, &cIf_2rAZ7eA9_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_FVKIxH6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2rAZ7eA9, 0, m, &cIf_2rAZ7eA9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_rOaAPNAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S7cMoNSG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_rfkMAiCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S7cMoNSG, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cIf_Rilrslz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KXjyFcQH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_zVDUrtc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eAkr44u5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cSwitchcase_lkHgbmvp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YLZ6wjF4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YLZ6wjF4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_guEmzF4d, 1, m, &cDelay_guEmzF4d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lHmWtYW8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_guEmzF4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_guEmzF4d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Rilrslz6, 0, m, &cIf_Rilrslz6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_YLZ6wjF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_guEmzF4d, 0, m, &cDelay_guEmzF4d_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_lHmWtYW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_guEmzF4d, 0, m, &cDelay_guEmzF4d_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_5kOxNmp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_icZh4rlC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GSHapCEN_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_aimVlW5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pdCL7IYL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3odmY0eX_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_3odmY0eX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lkHgbmvp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_pdCL7IYL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rilrslz6, 1, m, &cIf_Rilrslz6_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_GSHapCEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zVDUrtc1, 0, m, &cIf_zVDUrtc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_icZh4rlC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zVDUrtc1, 1, m, &cIf_zVDUrtc1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_eAkr44u5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t3I1cexD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KXjyFcQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_t3I1cexD, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_akD7ABTK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_D94qc2dH_sendMessage(_c, 0, m);
  cMsg_msMoiaIb_sendMessage(_c, 0, m);
  cMsg_FvYPStaA_sendMessage(_c, 0, m);
  cMsg_rKAHLR8N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5xVifGEo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_D94qc2dH_sendMessage(_c, 0, m);
  cMsg_cBjbFqQl_sendMessage(_c, 0, m);
  cMsg_5f0ixu9U_sendMessage(_c, 0, m);
  cMsg_ZChkIWhh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_zi0QNVoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_p0DZZzt4_sendMessage(_c, 0, m);
  cMsg_cBjbFqQl_sendMessage(_c, 0, m);
  cMsg_rKAHLR8N_sendMessage(_c, 0, m);
  cMsg_Kwx14rqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_T2eAuBkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_p0DZZzt4_sendMessage(_c, 0, m);
  cMsg_CPBvGS77_sendMessage(_c, 0, m);
  cMsg_FvYPStaA_sendMessage(_c, 0, m);
  cMsg_Nxbk4k7c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Qz42DjJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_aT6ePGOa_sendMessage(_c, 0, m);
  cMsg_ZChkIWhh_sendMessage(_c, 0, m);
  cMsg_jN1UxAbW_sendMessage(_c, 0, m);
  cMsg_FvYPStaA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_XgCFVtmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_aT6ePGOa_sendMessage(_c, 0, m);
  cMsg_Nxbk4k7c_sendMessage(_c, 0, m);
  cMsg_cBjbFqQl_sendMessage(_c, 0, m);
  cMsg_FMTpLbxQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BlhUQv4m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R8gomU33_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_74S6PjQC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_18gvczkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R8gomU33_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_74S6PjQC_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_qVCyYeZv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8NTL4iXg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x4HZq0t6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_3Ze0aTAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8NTL4iXg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x4HZq0t6_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_bkuqn0rU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y7Sb8wqG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DEGrO4St_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_gBDyXjgt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y7Sb8wqG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DEGrO4St_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_D94qc2dH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_BlhUQv4m_sendMessage(_c, 0, m);
  cMsg_3Ze0aTAS_sendMessage(_c, 0, m);
  cMsg_gBDyXjgt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_p0DZZzt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_18gvczkR_sendMessage(_c, 0, m);
  cMsg_qVCyYeZv_sendMessage(_c, 0, m);
  cMsg_gBDyXjgt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_aT6ePGOa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_18gvczkR_sendMessage(_c, 0, m);
  cMsg_3Ze0aTAS_sendMessage(_c, 0, m);
  cMsg_bkuqn0rU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_wBA984p0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sEV6MwhP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eWJ4Di6k_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_zHQK7cd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sEV6MwhP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eWJ4Di6k_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_AC990CTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yTLacEJN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YkDUOvMR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_oljzandX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yTLacEJN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YkDUOvMR_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_EC4d8F6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iI1ovW82_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_37paZZiS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_VTNT66zJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iI1ovW82_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_37paZZiS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_cBjbFqQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_zHQK7cd3_sendMessage(_c, 0, m);
  cMsg_oljzandX_sendMessage(_c, 0, m);
  cMsg_VTNT66zJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_msMoiaIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_zHQK7cd3_sendMessage(_c, 0, m);
  cMsg_AC990CTj_sendMessage(_c, 0, m);
  cMsg_EC4d8F6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_CPBvGS77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_wBA984p0_sendMessage(_c, 0, m);
  cMsg_oljzandX_sendMessage(_c, 0, m);
  cMsg_EC4d8F6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_qa8mAMxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6rDooRNm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8HXFiBP9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_8GWOvjhq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6rDooRNm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_8HXFiBP9_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JiYtQdo0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AJob8Akl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gGVkVGhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_7SJ0rPfF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AJob8Akl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gGVkVGhH_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_yvCPsyHU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aimVlW5B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5kOxNmp1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_wd1T3Qzj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aimVlW5B_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5kOxNmp1_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Nxbk4k7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_qa8mAMxi_sendMessage(_c, 0, m);
  cMsg_7SJ0rPfF_sendMessage(_c, 0, m);
  cMsg_wd1T3Qzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_ZChkIWhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_8GWOvjhq_sendMessage(_c, 0, m);
  cMsg_JiYtQdo0_sendMessage(_c, 0, m);
  cMsg_wd1T3Qzj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_rKAHLR8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_8GWOvjhq_sendMessage(_c, 0, m);
  cMsg_7SJ0rPfF_sendMessage(_c, 0, m);
  cMsg_yvCPsyHU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_usMfxR4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RodfGRjS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XDptWZGF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_WRP0nwlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RodfGRjS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XDptWZGF_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_JRVObvxo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3dCJeADb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_er2ad3NM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_Snedp0Y4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_3dCJeADb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_er2ad3NM_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_UsM53QNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uFCdul2r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L5DH9B2i_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_0JC2x7wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_uFCdul2r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_L5DH9B2i_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_FvYPStaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_WRP0nwlh_sendMessage(_c, 0, m);
  cMsg_Snedp0Y4_sendMessage(_c, 0, m);
  cMsg_0JC2x7wk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5f0ixu9U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_WRP0nwlh_sendMessage(_c, 0, m);
  cMsg_JRVObvxo_sendMessage(_c, 0, m);
  cMsg_UsM53QNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_FMTpLbxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_usMfxR4N_sendMessage(_c, 0, m);
  cMsg_JRVObvxo_sendMessage(_c, 0, m);
  cMsg_0JC2x7wk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_jN1UxAbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_wBA984p0_sendMessage(_c, 0, m);
  cMsg_AC990CTj_sendMessage(_c, 0, m);
  cMsg_VTNT66zJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_Kwx14rqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_usMfxR4N_sendMessage(_c, 0, m);
  cMsg_Snedp0Y4_sendMessage(_c, 0, m);
  cMsg_UsM53QNv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cVar_PUf6eJ3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HgssAcWI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_7t1VdY7V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AYjBUqu4, 0, m, &cSlice_AYjBUqu4_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TfYmGpQP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_AYjBUqu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_glJc7taX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_glJc7taX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_L1UYjPJ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_glJc7taX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_glJc7taX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AiZotM6x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_WRJ0aLaH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7bf8o5fz, 0, m, &cSlice_7bf8o5fz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_piW1oxdR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_7bf8o5fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mZpIvdmA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mZpIvdmA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_pU8MdmVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mZpIvdmA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_mZpIvdmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DusBExB8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_piW1oxdR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_SeJ3ER0g, 0, m, &cSlice_SeJ3ER0g_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7t1VdY7V_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_SeJ3ER0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Uc833hDi_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Uc833hDi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_U8OI3DhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Uc833hDi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Uc833hDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hyHddeDg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_TfYmGpQP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_43oipOrH, 0, m, &cSlice_43oipOrH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kJlLZkz1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_43oipOrH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_oLpPPKrt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_oLpPPKrt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_ACbcRTQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_oLpPPKrt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_oLpPPKrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R2woWGt5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_kJlLZkz1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_jXZ4ZJbD, 0, m, &cSlice_jXZ4ZJbD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MJw5j7RJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_jXZ4ZJbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gK7Omk6t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gK7Omk6t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_7qzLFXf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gK7Omk6t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_gK7Omk6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XoxzzGzZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSwitchcase_F70XM4li_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_BWxUzRCN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_BWxUzRCN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7HBM9dgZ, 1, m, &cDelay_7HBM9dgZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rF0wp3gv_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cDelay_7HBM9dgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7HBM9dgZ, m);
  cMsg_xTGAC3mJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_BWxUzRCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7HBM9dgZ, 0, m, &cDelay_7HBM9dgZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_rF0wp3gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7HBM9dgZ, 0, m, &cDelay_7HBM9dgZ_sendMessage);
}

void Heavy_WSTD_MANGLR::cVar_YCjk33GS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ols64H1e, HV_BINOP_SUBTRACT, 0, m, &cBinop_ols64H1e_sendMessage);
}

void Heavy_WSTD_MANGLR::cIf_ajW4DVTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RtQbz2AY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cIf_FR7pgYfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RtQbz2AY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::sEnv_QImdAypF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YCjk33GS, 0, m, &cVar_YCjk33GS_sendMessage);
}

void Heavy_WSTD_MANGLR::sEnv_EWNgFNwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VbafmVT8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tf6ou2Wg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S2EE06sV_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_ols64H1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IhxdDzQU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_IhxdDzQU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Zn6nfc98_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_Zn6nfc98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_q0hzet1g_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_yTmwIorF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wqCDokfq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ser1i45H_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_ser1i45H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_01Bim7zu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_wqCDokfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ajW4DVTm, 1, m, &cIf_ajW4DVTm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_bcWLRWbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FR7pgYfO, 1, m, &cIf_FR7pgYfO_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_01Bim7zu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ajW4DVTm, 0, m, &cIf_ajW4DVTm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_q0hzet1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FR7pgYfO, 0, m, &cIf_FR7pgYfO_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_Tf6ou2Wg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ols64H1e, HV_BINOP_SUBTRACT, 1, m, &cBinop_ols64H1e_sendMessage);
}

void Heavy_WSTD_MANGLR::cCast_VbafmVT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_MANGLR::cCast_S2EE06sV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YCjk33GS, 0, m, &cVar_YCjk33GS_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RtQbz2AY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kVq9LUeB, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSwitchcase_MJw5j7RJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6mGm0U5u, 0, m, &cSlice_6mGm0U5u_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_MANGLR::cSlice_6mGm0U5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z4rycLYE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z4rycLYE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_MANGLR::cVar_lhuw3fIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z4rycLYE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cSend_Z4rycLYE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pMmR5zFV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_fwHbN8xX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_L01SeuM5, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_fRs7RE8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bYxnjsfj, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_lEoeiMvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MTypVfPU, 0, m, &cVar_MTypVfPU_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_HgssAcWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZUqkRzHO, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cCast_USsNmrQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wYObGNMW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cCast_vZheyvk3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F70XM4li_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_xTGAC3mJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LrL9CPCH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_wYObGNMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LrL9CPCH, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_zRpt6ZYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_BK7jLrPm_sendMessage);
}

void Heavy_WSTD_MANGLR::cBinop_BK7jLrPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SUN7OFeG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_SUN7OFeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pVIQlwOl, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cVar_FS3jEYjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RcoHujZk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_5Wl3MPF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iK1pN3x2, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_YeQSLYkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_flgTNvt7, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cSend_23yPFRU2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cRLfsysc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cMsg_n06vLOEi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ikJt04rK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WRJ0aLaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_5VcXYvE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ikJt04rK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WRJ0aLaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cBinop_hQMPyVij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_blpAr6Fx, 0, m, &cVar_blpAr6Fx_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_vqyLxUOX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ikJt04rK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WRJ0aLaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_GxPafQem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ikJt04rK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WRJ0aLaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_KLSzm3k0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ikJt04rK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WRJ0aLaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_qEWiF8bK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_LaE6xr3f, 0, m, &cVar_LaE6xr3f_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_ofhwRpdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_pbwm43QQ, 0, m, &cVar_pbwm43QQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xhp43NnP, 0, m, &cVar_Xhp43NnP_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_xHWf0cTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hQMPyVij_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_DUPzdKHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_gkjmkDor, 0, m, &cVar_gkjmkDor_sendMessage);
}

void Heavy_WSTD_MANGLR::cMsg_RcoHujZk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_ikJt04rK_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_WRJ0aLaH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_MANGLR::cMsg_kVY6SkOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_FS3jEYjT, 0, m, &cVar_FS3jEYjT_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_cRLfsysc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_JTWgeGDp_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_E77lo2FU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_En5e49RQ, 0, m, &cVar_En5e49RQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_bGqHv10U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_hQMPyVij_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_ymBAWkfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LaE6xr3f, 0, m, &cVar_LaE6xr3f_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_EQCYsFW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mSxIhTV1, 0, m, &cVar_mSxIhTV1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jI7ZH33A, 0, m, &cVar_jI7ZH33A_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GNLQ9iQS, 0, m, &cVar_GNLQ9iQS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TUeoXgkL, 0, m, &cVar_TUeoXgkL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mQuOaVYA, 0, m, &cVar_mQuOaVYA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8n7yHsur, 0, m, &cVar_8n7yHsur_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L1UYjPJ2, 0, m, &cVar_L1UYjPJ2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pU8MdmVI, 0, m, &cVar_pU8MdmVI_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_U8OI3DhF, 0, m, &cVar_U8OI3DhF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ACbcRTQZ, 0, m, &cVar_ACbcRTQZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7qzLFXf7, 0, m, &cVar_7qzLFXf7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lhuw3fIM, 0, m, &cVar_lhuw3fIM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LA2b11BP_sendMessage);
  cMsg_DUPzdKHS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_DW9RFNHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gkjmkDor, 0, m, &cVar_gkjmkDor_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_BSKUp0uP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pbwm43QQ, 0, m, &cVar_pbwm43QQ_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_tCCMFW09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Xhp43NnP, 0, m, &cVar_Xhp43NnP_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_JMxcAkm7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PRuM8cl8, 0, m, &cVar_PRuM8cl8_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_9hMbRPGt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4i5fYZFj, 0, m, &cVar_4i5fYZFj_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_6dNGSs3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_BPqBhXXd_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_IL5oL3wH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1URAECSm_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8jncoog1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L0adq96C_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_rqap1zsf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qQbra6Tl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4azfOEQV_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_0rjgeTYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KPP8Il8i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_AiZotM6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3huzPwC4, 0, m, &cVar_3huzPwC4_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_R2woWGt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PUf6eJ3T, 0, m, &cVar_PUf6eJ3T_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_hyHddeDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_lEoeiMvy_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_DusBExB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3gnidjrY_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_USsNmrQd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vZheyvk3_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_XoxzzGzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yTmwIorF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bcWLRWbM_sendMessage);
}

void Heavy_WSTD_MANGLR::cReceive_pMmR5zFV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zRpt6ZYC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_MANGLR::cReceive_75yzm06f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FS3jEYjT, 0, m, &cVar_FS3jEYjT_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_MANGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varwrite_f(&sVarf_VrHYT66W, VIf(I0));
    __hv_varread_f(&sVarf_KHzI6wLs, VOf(Bf0));
    __hv_varread_f(&sVarf_II8lJ8qw, VOf(Bf1));
    __hv_varread_f(&sVarf_iRA023Rq, VOf(Bf2));
    __hv_varread_f(&sVarf_NVDDVs3D, VOf(Bf3));
    __hv_varread_f(&sVarf_RoECiHKO, VOf(Bf4));
    __hv_varread_f(&sVarf_2PVSYIHL, VOf(Bf5));
    __hv_varread_f(&sVarf_2RrpSq9x, VOf(Bf6));
    __hv_varwrite_f(&sVarf_8XjiEgp0, VIf(I0));
    __hv_varread_f(&sVarf_DHRHQZNt, VOf(Bf7));
    __hv_line_f(&sLine_jzsdNaYm, VOf(Bf8));
    __hv_mul_f(VIf(Bf7), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_EJDFkc19, VOf(Bf9));
    __hv_line_f(&sLine_nCkqt59U, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_02Pg92VY, VOf(Bf8));
    __hv_line_f(&sLine_jF0Y2asR, VOf(Bf11));
    __hv_mul_f(VIf(Bf8), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varwrite_f(&sVarf_NVDDVs3D, VIf(Bf11));
    __hv_varread_f(&sVarf_8XjiEgp0, VOf(Bf11));
    __hv_line_f(&sLine_C2bPcCay, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_WW7ak4vb, VOf(Bf12));
    __hv_mul_f(VIf(Bf8), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_KIP3Sycb, VOf(Bf10));
    __hv_mul_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_RoECiHKO, VIf(Bf10));
    __hv_line_f(&sLine_RQtLcHpg, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_pd3omEAd, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_E352qLFW, VOf(Bf10));
    __hv_mul_f(VIf(Bf8), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_2PVSYIHL, VIf(Bf10));
    __hv_line_f(&sLine_7oqO1iEt, VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_Az7lmNHU, VOf(Bf11));
    __hv_mul_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_add_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_53zPH6kP, VOf(Bf10));
    __hv_mul_f(VIf(Bf7), VIf(Bf10), VOf(Bf10));
    __hv_add_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_2RrpSq9x, VIf(Bf10));
    __hv_varwrite_f(&sVarf_DHRHQZNt, VIf(Bf0));
    __hv_varwrite_f(&sVarf_EJDFkc19, VIf(Bf1));
    __hv_varwrite_f(&sVarf_02Pg92VY, VIf(Bf2));
    sEnv_process(this, &sEnv_H7YTb8sx, VIf(Bf3), &sEnv_H7YTb8sx_sendMessage);
    sEnv_process(this, &sEnv_TFESkRSJ, VIf(I0), &sEnv_TFESkRSJ_sendMessage);
    __hv_line_f(&sLine_Sjs09Sbn, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ild1tk0M, VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_KhzK8kGL, VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_exp_f(VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_2y4iqu3u, VOf(Bf3));
    __hv_line_f(&sLine_d6g5m1uh, VOf(Bf1));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf3), VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_sub_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf3), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_KHzI6wLs, VIf(Bf0));
    __hv_varwrite_f(&sVarf_2y4iqu3u, VIf(Bf4));
    __hv_varwrite_f(&sVarf_kMqRQs9k, VIf(Bf5));
    __hv_varwrite_f(&sVarf_6ZDKlb3O, VIf(Bf6));
    __hv_varread_f(&sVarf_6ZDKlb3O, VOf(Bf6));
    __hv_line_f(&sLine_PPzwPZb1, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf5), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_mul_f(VIf(Bf5), VIf(Bf5), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf6), VIf(Bf4), VOf(Bf0));
    __hv_var_k_f(VOf(Bf3), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_div_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_iRA023Rq, VIf(Bf4));
    __hv_varread_f(&sVarf_kMqRQs9k, VOf(Bf4));
    __hv_line_f(&sLine_UOhtJSe0, VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf4), VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_floor_f(VIf(Bf5), VOf(Bf0));
    __hv_sub_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf5), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_abs_f(VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf5), VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_neg_f(VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_II8lJ8qw, VIf(Bf4));
    __hv_varwrite_f(&sVarf_kQCxbOPc, VIf(Bf2));
    __hv_varwrite_f(&sVarf_R6NJ7rH4, VIf(I1));
    __hv_varread_f(&sVarf_8nfgyzJx, VOf(Bf2));
    __hv_varread_f(&sVarf_v2n7U0Op, VOf(Bf4));
    __hv_varread_f(&sVarf_uoYELukh, VOf(Bf0));
    __hv_varread_f(&sVarf_kuYco5E5, VOf(Bf5));
    __hv_varread_f(&sVarf_mUrTflXh, VOf(Bf3));
    __hv_varread_f(&sVarf_vh3mZbhX, VOf(Bf6));
    __hv_varread_f(&sVarf_PhCT8Muq, VOf(Bf1));
    __hv_varwrite_f(&sVarf_LaWHLmOD, VIf(I1));
    __hv_varread_f(&sVarf_6U2Jw3bo, VOf(Bf10));
    __hv_line_f(&sLine_BzgbXKfX, VOf(Bf11));
    __hv_mul_f(VIf(Bf10), VIf(Bf11), VOf(Bf11));
    __hv_varread_f(&sVarf_fZcyKz6p, VOf(Bf7));
    __hv_line_f(&sLine_S7cMoNSG, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_5PpWaXzJ, VOf(Bf11));
    __hv_line_f(&sLine_t3I1cexD, VOf(Bf12));
    __hv_mul_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_kuYco5E5, VIf(Bf12));
    __hv_varread_f(&sVarf_LaWHLmOD, VOf(Bf12));
    __hv_line_f(&sLine_IqbIOaMP, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_hYZx748e, VOf(Bf8));
    __hv_mul_f(VIf(Bf11), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_lETb5IG1, VOf(Bf9));
    __hv_mul_f(VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_mUrTflXh, VIf(Bf9));
    __hv_line_f(&sLine_GuGVgj7U, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_NvzKyEBd, VOf(Bf8));
    __hv_mul_f(VIf(Bf10), VIf(Bf8), VOf(Bf8));
    __hv_add_f(VIf(Bf9), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_ttL8AaaY, VOf(Bf9));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf8), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_vh3mZbhX, VIf(Bf9));
    __hv_line_f(&sLine_DgQKzH8s, VOf(Bf9));
    __hv_mul_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_SITd45gn, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf9), VIf(Bf12), VOf(Bf12));
    __hv_line_f(&sLine_R6E5LEgd, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_add_f(VIf(Bf12), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_PhCT8Muq, VIf(Bf9));
    __hv_varwrite_f(&sVarf_6U2Jw3bo, VIf(Bf2));
    __hv_varwrite_f(&sVarf_fZcyKz6p, VIf(Bf4));
    __hv_varwrite_f(&sVarf_5PpWaXzJ, VIf(Bf0));
    sEnv_process(this, &sEnv_QImdAypF, VIf(Bf5), &sEnv_QImdAypF_sendMessage);
    sEnv_process(this, &sEnv_EWNgFNwY, VIf(I1), &sEnv_EWNgFNwY_sendMessage);
    __hv_line_f(&sLine_kVq9LUeB, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_LrL9CPCH, VOf(Bf5));
    __hv_mul_f(VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_pVIQlwOl, VOf(Bf0));
    __hv_var_k_f(VOf(Bf4), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf4), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_8ykUBkG2, VOf(Bf5));
    __hv_line_f(&sLine_bYxnjsfj, VOf(Bf4));
    __hv_var_k_f(VOf(Bf2), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_floor_f(VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_sub_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_div_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_8nfgyzJx, VIf(Bf2));
    __hv_varwrite_f(&sVarf_8ykUBkG2, VIf(Bf3));
    __hv_varwrite_f(&sVarf_KNSsClXp, VIf(Bf6));
    __hv_varwrite_f(&sVarf_6uwTpxkw, VIf(Bf1));
    __hv_varread_f(&sVarf_6uwTpxkw, VOf(Bf1));
    __hv_line_f(&sLine_ZUqkRzHO, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf6), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf2));
    __hv_var_k_f(VOf(Bf5), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_div_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_uoYELukh, VIf(Bf3));
    __hv_varread_f(&sVarf_KNSsClXp, VOf(Bf3));
    __hv_line_f(&sLine_L01SeuM5, VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf3), VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_floor_f(VIf(Bf6), VOf(Bf2));
    __hv_sub_f(VIf(Bf6), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf6), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_abs_f(VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf6), VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_neg_f(VIf(Bf3), VOf(Bf3));
    __hv_varwrite_f(&sVarf_v2n7U0Op, VIf(Bf3));
    __hv_varwrite_f(&sVarf_VfMpuEw0, VIf(Bf0));
    __hv_varread_f(&sVarf_VrHYT66W, VOf(Bf0));
    __hv_line_f(&sLine_flgTNvt7, VOf(Bf3));
    __hv_varread_f(&sVarf_kQCxbOPc, VOf(Bf2));
    __hv_line_f(&sLine_iK1pN3x2, VOf(Bf6));
    __hv_mul_f(VIf(Bf2), VIf(Bf6), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_R6NJ7rH4, VOf(Bf2));
    __hv_varread_f(&sVarf_VfMpuEw0, VOf(Bf0));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf2), VIf(Bf3), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf6), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_MANGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_MANGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
